package cn.ezhizao.project.business.app.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import cn.ezhizao.common.utils.poi.ExcelUtil;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.business.app.domain.BizApp;
import cn.ezhizao.project.business.app.service.IBizAppService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * app管理Controller
 *
 * @author ezhizao
 * @date 2024-01-24
 */
@RestController
@RequestMapping("/business/app")
public class BizAppController extends BaseController
{
    @Resource
    private IBizAppService bizAppService;

    /**
     * 查询app管理列表
     */
//    @PreAuthorize("@ss.hasPermi('business:app:list')")
    @Log(title = "app管理", businessType = BusinessType.SELECT)
    @GetMapping("/list")
    public TableDataInfo list(BizApp bizApp) throws NoSuchFieldException, IllegalAccessException
    {
//        setTenantId(bizApp);
//        startPage();
        List<BizApp> list = bizAppService.getList(bizApp);
        return getDataTable(list);
    }

    /**
     * 导出app管理列表
     */
//    @PreAuthorize("@ss.hasPermi('business:app:export')")
    @Log(title = "app管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizApp bizApp) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizApp);
        List<BizApp> list = bizAppService.getList(bizApp);
        ExcelUtil<BizApp> util = new ExcelUtil<BizApp>(BizApp.class);
        util.exportExcel(response, list, "app管理数据");
    }

    /**
     * 获取app管理详细信息
     */
//    @PreAuthorize("@ss.hasPermi('business:app:query')")
    @GetMapping(value = "/{id}")
    @Log(title = "app管理", businessType = BusinessType.SELECT)
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizAppService.getById(id));
    }

    /**
     * 新增app管理
     */
//    @PreAuthorize("@ss.hasPermi('business:app:add')")
    @Log(title = "app管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizApp bizApp) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizApp);
        return toAjax(bizAppService.save(bizApp));
    }

    /**
     * 修改app管理
     */
//    @PreAuthorize("@ss.hasPermi('business:app:edit')")
    @Log(title = "app管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizApp bizApp) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizApp);
        return toAjax(bizAppService.updateById(bizApp));
    }

    /**
     * 删除app管理
     */
//    @PreAuthorize("@ss.hasPermi('business:app:remove')")
    @Log(title = "app管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(bizAppService.removeBatchByIds(ids));
    }
}
