package cn.ezhizao.project.business.equipment.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import cn.ezhizao.common.utils.poi.ExcelUtil;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.business.equipment.domain.BizUserEquipment;
import cn.ezhizao.project.business.equipment.service.IBizUserEquipmentService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 员工绑定设备Controller
 *
 * @author ezhizao
 * @date 2023-12-08
 */
@RestController
@RequestMapping("/business/userEquipment")
public class BizUserEquipmentController extends BaseController {
    @Resource
    private IBizUserEquipmentService bizUserEquipmentService;

    /**
     * 查询员工绑定设备列表
     */
//    @PreAuthorize("@ss.hasPermi('business:equipment:list')")
    @GetMapping("/list")
    @Log(title = "查询员工绑定的设备列表", businessType = BusinessType.SELECT)
    public TableDataInfo list(BizUserEquipment bizUserEquipment) throws NoSuchFieldException, IllegalAccessException {
        setTenantId(bizUserEquipment);
//        startPage();
        List<BizUserEquipment> list = bizUserEquipmentService.getList(bizUserEquipment);
        return getDataTable(list);
    }

    /**
     * 导出员工绑定设备列表
     */
//    @PreAuthorize("@ss.hasPermi('business:equipment:export')")
    @Log(title = "导出员工绑定设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizUserEquipment bizUserEquipment) throws NoSuchFieldException, IllegalAccessException {
        setTenantId(bizUserEquipment);
        List<BizUserEquipment> list = bizUserEquipmentService.getList(bizUserEquipment);
        ExcelUtil<BizUserEquipment> util = new ExcelUtil<BizUserEquipment>(BizUserEquipment.class);
        util.exportExcel(response, list, "员工绑定设备数据");
    }

    /**
     * 获取员工绑定设备详细信息
     */
//    @PreAuthorize("@ss.hasPermi('business:equipment:query')")
    @GetMapping(value = "/{id}")
    @Log(title = "查询员工绑定设备信息", businessType = BusinessType.SELECT)
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bizUserEquipmentService.getById(id));
    }

    /**
     * 新增员工绑定设备
     */
//    @PreAuthorize("@ss.hasPermi('business:equipment:add')")
    @Log(title = "员工绑定设备", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizUserEquipment bizUserEquipment) throws NoSuchFieldException, IllegalAccessException {
        setTenantId(bizUserEquipment);
        return toAjax(bizUserEquipmentService.save(bizUserEquipment));
    }

    /**
     * 修改员工绑定设备
     */
//    @PreAuthorize("@ss.hasPermi('business:equipment:edit')")
    @Log(title = "员工绑定设备", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizUserEquipment bizUserEquipment) throws NoSuchFieldException, IllegalAccessException {
        setTenantId(bizUserEquipment);
        return toAjax(bizUserEquipmentService.updateById(bizUserEquipment));
    }

    /**
     * 删除员工绑定设备
     */
//    @PreAuthorize("@ss.hasPermi('business:equipment:remove')")
    @Log(title = "删除员工绑定设备", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids) {
        return toAjax(bizUserEquipmentService.removeBatchByIds(ids));
    }

//    @Log(title = "保存员工绑定设备信息", businessType = BusinessType.INSERT)
//    @PostMapping("/saveUserEquipment")
//    public AjaxResult saveUserEquipment(BizUserEquipment bizUserEquipment) throws NoSuchFieldException, IllegalAccessException {
//        int i = bizUserEquipmentService.saveUserEquipment(bizUserEquipment);
//        if (i > 0) {
//            return AjaxResult.success();
//        }
//        return AjaxResult.error();
//    }
}