package cn.ezhizao.project.business.outsource.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import cn.ezhizao.common.utils.poi.ExcelUtil;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import cn.ezhizao.project.business.outsource.domain.BizOutsourcedOrderDetail;
import cn.ezhizao.project.business.outsource.service.IBizOutsourcedOrderDetailService;

/**
 * 外协单从Controller
 *
 * @author ezhizao
 * @date 2024-05-28
 */
@RestController
@RequestMapping("/business/outsourcedOrderDetail")
public class BizOutsourcedOrderDetailController extends BaseController
{
    @Resource
    private IBizOutsourcedOrderDetailService bizOutsourcedOrderDetailService;

    /**
     * 查询外协单从列表
     */
    @GetMapping("/list")
    @Log(title = "查询外协单明细列表", businessType = BusinessType.SELECT)
    public TableDataInfo list(BizOutsourcedOrderDetail bizOutsourcedOrderDetail) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizOutsourcedOrderDetail);
        startPage();
        List<BizOutsourcedOrderDetail> list = bizOutsourcedOrderDetailService.getList(bizOutsourcedOrderDetail);
        return getDataTable(list);
    }

    /**
     * 导出外协单从列表
     */
    @Log(title = "导出外协明细列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizOutsourcedOrderDetail bizOutsourcedOrderDetail) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizOutsourcedOrderDetail);
        List<BizOutsourcedOrderDetail> list = bizOutsourcedOrderDetailService.getList(bizOutsourcedOrderDetail);
        ExcelUtil<BizOutsourcedOrderDetail> util = new ExcelUtil<BizOutsourcedOrderDetail>(BizOutsourcedOrderDetail.class);
        util.exportExcel(response, list, "外协单从数据");
    }

    /**
     * 获取外协单从详细信息
     */
    @GetMapping(value = "/{id}")
    @Log(title = "获取外协单明细信息", businessType = BusinessType.SELECT)
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizOutsourcedOrderDetailService.getById(id));
    }

    /**
     * 新增外协单从
     */
    @Log(title = "新增外协单明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizOutsourcedOrderDetail bizOutsourcedOrderDetail) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizOutsourcedOrderDetail);
        return toAjax(bizOutsourcedOrderDetailService.save(bizOutsourcedOrderDetail));
    }

    /**
     * 修改外协单从
     */
    @Log(title = "编辑外协单明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizOutsourcedOrderDetail bizOutsourcedOrderDetail) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizOutsourcedOrderDetail);
        return toAjax(bizOutsourcedOrderDetailService.updateById(bizOutsourcedOrderDetail));
    }

    /**
     * 删除外协单从
     */
    @Log(title = "删除外协单明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(bizOutsourcedOrderDetailService.removeBatchByIds(ids));
    }
}
