package cn.ezhizao.project.business.product.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import cn.ezhizao.common.utils.poi.ExcelUtil;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.business.product.domain.BizInspectionChamber;
import cn.ezhizao.project.business.product.service.IBizInspectionChamberService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 检测室配置Controller
 *
 * @author ezhizao
 * @date 2024-08-06
 */
@RestController
@RequestMapping("/business/inspectionChamber")
public class BizInspectionChamberController extends BaseController
{
    @Resource
    private IBizInspectionChamberService bizInspectionChamberService;

    /**
     * 查询检测室配置列表
     */
    @GetMapping("/list")
    @Log(title = "检查室列表", businessType = BusinessType.INSERT)
    public TableDataInfo list(BizInspectionChamber bizInspectionChamber) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizInspectionChamber);
        List<BizInspectionChamber> list = bizInspectionChamberService.getList(bizInspectionChamber);
        return getDataTable(list);
    }

    /**
     * 导出检测室配置列表
     */
    @PreAuthorize("@ss.hasPermi('business:inspectionChamber:export')")
    @Log(title = "导出检测室配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizInspectionChamber bizInspectionChamber) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizInspectionChamber);
        List<BizInspectionChamber> list = bizInspectionChamberService.getList(bizInspectionChamber);
        ExcelUtil<BizInspectionChamber> util = new ExcelUtil<BizInspectionChamber>(BizInspectionChamber.class);
        util.exportExcel(response, list, "检测室配置数据");
    }

    /**
     * 获取检测室配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:inspectionChamber:query')")
    @Log(title = "获取检查室信息", businessType = BusinessType.INSERT)
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizInspectionChamberService.getById(id));
    }

    /**
     * 新增检测室配置
     */
    @PreAuthorize("@ss.hasPermi('business:inspectionChamber:add')")
    @Log(title = "新增检测室配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizInspectionChamber bizInspectionChamber) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizInspectionChamber);
        return toAjax(bizInspectionChamberService.save(bizInspectionChamber));
    }

    /**
     * 修改检测室配置
     */
    @PreAuthorize("@ss.hasPermi('business:inspectionChamber:edit')")
    @Log(title = "修改检测室配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizInspectionChamber bizInspectionChamber) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizInspectionChamber);
        return toAjax(bizInspectionChamberService.updateById(bizInspectionChamber));
    }

    /**
     * 删除检测室配置
     */
    @PreAuthorize("@ss.hasPermi('business:inspectionChamber:remove')")
    @Log(title = "删除检测室配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(bizInspectionChamberService.removeBatchByIds(ids));
    }
}
