package cn.ezhizao.project.business.product.controller;

import cn.ezhizao.common.utils.SecurityUtils;
import cn.ezhizao.common.utils.uuid.SnowflakeIdWorker;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.business.deptProcess.domain.BizDeptProcess;
import cn.ezhizao.project.business.deptProcess.service.IBizDeptProcessService;
import cn.ezhizao.project.business.process.domain.BizProcess;
import cn.ezhizao.project.business.product.domain.*;
import cn.ezhizao.project.business.product.service.*;
import cn.ezhizao.project.business.resourceGroup.domain.BizProductionResourceGroupDetail;
import cn.ezhizao.project.business.resourceGroup.domain.BizProductionResourceGroupSubPlan;
import cn.ezhizao.project.business.resourceGroup.service.IBizProductionResourceGroupDetailService;
import cn.ezhizao.project.business.resourceGroup.service.IBizProductionResourceGroupService;
import cn.ezhizao.project.business.resourceGroup.service.IBizProductionResourceGroupSubPlanService;
import cn.ezhizao.project.business.turnover.service.IBizTurnoverService;
import cn.ezhizao.project.business.workshop.domain.BizWorkshop;
import cn.ezhizao.project.business.workshop.service.IBizWorkshopService;
import cn.ezhizao.project.business.workshop.service.IBizWorkshopTurnoverService;
import cn.ezhizao.project.system.domain.SysDept;
import cn.ezhizao.project.system.domain.SysUser;
import cn.ezhizao.project.system.service.ISysDeptService;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.stream.Collectors;

/**
 * 快速报工记录Controller
 *
 * @author ezhizao
 * @date 2024-04-04
 */
@RestController
@RequestMapping("/business/quickDaywork")
public class BizQuickDayworkController extends BaseController {
    @Resource
    private IBizDayworkService bizDayworkService;
    @Resource
    private IBizDayworkItemService bizDayworkItemService;
    @Resource
    private IBizCarrierService bizCarrierService;
    @Resource
    private IBizDayworkCarrierService bizDayworkCarrierService;
    @Resource
    private IBizLotService bizLotService;
    @Resource
    private IBizProductionPlanDetailService productionPlanDetailService;
    @Resource
    private IBizQuickDayworkNextInfoService quickDayworkNextInfoService;
    @Resource
    private IBizProductionResourceGroupSubPlanService bizProductionResourceGroupSubPlanService;

    @Resource
    private IBizProductionResourceGroupService bizProductionResourceGroupService;

    @Resource
    private IBizProductionResourceGroupDetailService bizProductionResourceGroupDetailService;

    @Resource
    private IBizWorkshopService workshopService;
    @Resource
    private ISysDeptService deptService;
    @Resource
    private IBizDeptProcessService deptProcessService;
    @Resource
    private IBizLotTechnologicalProcessService bizLotTechnologicalProcessService;
    @Resource
    private IBizLotTechnologicalProcessDetailService bizLotTechnologicalProcessDetailService;
    @Resource
    private IBizWorkshopTurnoverService bizWorkshopTurnoverService;
    @Resource
    private IBizTurnoverService bizTurnoverService;
    @Resource
    private IBizDayworkItemExamineService bizDayworkItemExamineService;
    @Resource
    HttpServletRequest request;

//    @Resource
//    SnowflakeIdWorker snowflakeIdWorker;

    // 获取快速报工列表
    @PostMapping("/list")
    @Log(title = "查询快速报工记录", businessType = BusinessType.SELECT)
    public TableDataInfo list(@RequestBody BizProductionPlanDetail bizProductionPlanDetail) throws NoSuchFieldException, IllegalAccessException {
        // 根据员工信息获取当前未完成的所有快速报工
        List<BizDayworkItem> list = bizDayworkItemService.getUnfinishedDayworkItemByUser(SecurityUtils.getLoginUser().getUser().getUserId());
//        List<BizLotTechnologicalProcess> tProcess = bizLotTechnologicalProcessService.query().eq("is_stop", 0).in("lot_id", list.isEmpty() ? Collections.singletonList("0") : list.stream().map(BizDayworkItem::getLotId).collect(Collectors.toList())).list();
//        List<BizLotTechnologicalProcessDetail> tProcessDetails = bizLotTechnologicalProcessDetailService.query().in("lot_technological_process_id", tProcess.isEmpty() ? Collections.singletonList(0L) : tProcess.stream().map(BizLotTechnologicalProcess::getId).collect(Collectors.toList())).list();
        List<Long> lotTechnologicalProcessIds = list.stream().map(BizDayworkItem::getTechnologicalProcessId).distinct().collect(Collectors.toList());
        List<BizLotTechnologicalProcessDetail> tProcessDetails = bizLotTechnologicalProcessDetailService.query().in("lot_technological_process_id", lotTechnologicalProcessIds.isEmpty() ? Collections.singletonList(0L) : list.stream().map(BizDayworkItem::getTechnologicalProcessId).distinct().collect(Collectors.toList())).list();
        List<BizProductionPlanDetail> details = productionPlanDetailService.query().in("id", list.isEmpty() ? Collections.singletonList("0") : list.stream().map(BizDayworkItem::getProductionPlanDetailId).collect(Collectors.toList())).list();
        // 获取箱号
        List<BizDayworkCarrier> dayworkCarriers = bizDayworkCarrierService.query().eq("process_inspection_id", 0L).eq("is_changed", 0).in("daywork_id", list.isEmpty() ? Collections.singletonList("0") : list.stream().map(BizDayworkItem::getDayworkId).collect(Collectors.toList())).list();
        List<BizDaywork> dayworks = bizDayworkService.query().in("id", list.isEmpty() ? Collections.singletonList(0L) : list.stream().map(BizDayworkItem::getDayworkId).collect(Collectors.toList())).list();
        // 获取临时周转信息
        List<BizQuickDayworkNextInfo> dayworkNextInfos = quickDayworkNextInfoService.query().in("daywork_item_id", list.isEmpty() ? Collections.singletonList("0") : list.stream().map(BizDayworkItem::getId).collect(Collectors.toList())).list();
        list.forEach(v -> {
            v.setBizProductionPlanDetail(details.stream().filter(l -> l.getId().equals(v.getProductionPlanDetailId())).findFirst().orElse(null));
            v.setDayworkCarriers(dayworkCarriers.stream().filter(l -> l.getDayworkId().equals(v.getDayworkId())).collect(Collectors.toList()));
            v.setQuickInfo(dayworkNextInfos.stream().filter(l -> l.getDayworkItemId().equals(v.getId())).findFirst().orElse(null));
            BizDaywork bizDaywork = dayworks.stream().filter(l -> l.getId().equals(v.getDayworkId())).findFirst().orElse(new BizDaywork());
            if (bizDaywork.getIsAmend().equals(1) || bizDaywork.getIsWasteRecycling().equals(1)) {
               // BizLotTechnologicalProcess p = tProcess.stream().filter(l -> l.getLotId().equals(v.getLotId())).findFirst().orElse(new BizLotTechnologicalProcess());
                List<BizLotTechnologicalProcessDetail> processDetails = tProcessDetails.stream().filter(t -> t.getLotTechnologicalProcessId().equals(v.getTechnologicalProcessId())).collect(Collectors.toList());
                v.setProcess(processDetails.stream().filter(l -> l.getId().equals(v.getTechnologicalProcessDetailId())).map(BizProcess::new).findFirst().orElse(new BizProcess()));
                v.setProcessSequence(processDetails.stream().map(BizProcess::new).collect(Collectors.toList()));
                v.setNextProcess(v.getProcessSequence().stream().filter(e -> e.getProcessStepNumber().compareTo(v.getProcess().getProcessStepNumber()) > 0).min(Comparator.comparing(BizProcess::getProcessStepNumber)).orElse(null));
            } else {
                v.setNextProcess(v.getProcessSequence().stream().filter(e -> e.getProcessStepNumber().compareTo(v.getTechnologicalProcessDetail().getProcessStepNumber()) > 0).min(Comparator.comparing(BizProcess::getProcessStepNumber)).orElse(null));
            }
        });
        Map<String, Object> result = new HashMap<>();
        // 车间信息
        if (!dayworkNextInfos.isEmpty()) {
            SysDept conditions = new SysDept();
            conditions.setDeptIds(dayworkNextInfos.stream().map(BizQuickDayworkNextInfo::getDeptId).collect(Collectors.toList()));
            List<SysDept> depts = deptService.selectDeptList(conditions);
            List<BizWorkshop> workshops = workshopService.query().in("id", depts.isEmpty() ? Collections.singletonList("0") : depts.stream().map(SysDept::getWorkshopId).collect(Collectors.toList())).list();
            workshops.forEach(l -> {
                l.setDepts(depts.stream().filter(v -> v.getWorkshopId().equals(l.getId())).collect(Collectors.toList()));
            });
            result.put("workShops", workshops);
        }
        TableDataInfo tableDataInfo = getDataTable(list);
        tableDataInfo.setOther(result);
        return tableDataInfo;
    }

    // 批量完成报工
    @PostMapping("/finishQuick")
    @Log(title = "快速报工结束报工", businessType = BusinessType.INSERT)
    @Transactional
    public AjaxResult finishQuick(@RequestBody List<BizDayworkItem> items) {
        List<BizDayworkItem> addItems = new ArrayList<>();
        List<BizDayworkItem> updateItems = new ArrayList<>();
        List<BizDaywork> updateDaywork = new ArrayList<>();
        if (items.isEmpty()) {
            return error("请求异常，请稍后再试。");
        }
        // 判断下都有哪些周转箱
        List<BizDayworkCarrier> dayworkCarriers = bizDayworkCarrierService.query().eq("process_inspection_id", 0L).in("daywork_id", items.stream().map(BizDayworkItem::getDayworkId).collect(Collectors.toList())).eq("is_changed", 0).list();
        // 判断是否有批次没绑箱
        if (items.stream().anyMatch(e -> dayworkCarriers.stream().noneMatch(t -> t.getDayworkId().equals(e.getDayworkId())))) {
            return error("有批次未绑定载具，请绑定后再结束");
        }
        // 判断下周转箱有哪些批次
        List<BizDaywork> dayworks = bizDayworkService.query().in("id", dayworkCarriers.stream().map(BizDayworkCarrier::getDayworkId).collect(Collectors.toList())).list();
        List<BizDayworkCarrier> allCarrier = bizDayworkCarrierService.query().eq("process_inspection_id", 0L).in("daywork_id", items.stream().map(BizDayworkItem::getDayworkId).collect(Collectors.toList())).list();
        List<BizDayworkItem> dayworkItemList = bizDayworkItemService.query().in("daywork_id", dayworks.stream().map(BizDaywork::getId).collect(Collectors.toList())).list();
        AtomicBoolean checkFinishBatch = new AtomicBoolean(true);
        for(BizDaywork l : dayworks) {
            //当前的步骤编码
            String processStepNumber = items.stream().filter(v -> v.getDayworkId().equals(l.getId())).findFirst().orElse(null).getProcessStepNumber();
            BizDayworkItem latestItem = dayworkItemList.stream().filter(v -> v.getDayworkId().equals(l.getId())).max(Comparator.comparing(BizDayworkItem::getCreateTime)).orElse(new BizDayworkItem());
            //如果latestItem中是周转状态，或者步骤编码跟当前的不一样，则返回错误
            if((latestItem.getStatus().equals("4") || latestItem.getStatus().equals("5") || latestItem.getStatus().equals("7")) || !processStepNumber.equals(latestItem.getProcessStepNumber())) {
                return error(l.getLotCode() + "批次已周转，请勿重复操作");
            }
            List<BizDayworkItem> currentItems = dayworkItemList.stream().filter(v -> v.getDayworkId().equals(l.getId()) && v.getTechnologicalProcessDetailId().equals(latestItem.getTechnologicalProcessDetailId())).sorted(Comparator.comparing(BizDayworkItem::getStatus)).collect(Collectors.toList());
            // 假设该批次报工不在选中报工中，且该报工中不存在已完成则判断周转箱中有未完成。
            if (currentItems.stream().noneMatch(v -> items.stream().anyMatch(e -> e.getId().equals(v.getId()))) && currentItems.stream().noneMatch(v -> v.getStatus().equals("3"))) {
                checkFinishBatch.set(false);
            }

            // 已经完成批次一起完成
            if (currentItems.stream().noneMatch(v -> v.getStatus().equals("3"))) {
                BizDayworkItem update = currentItems.stream().filter(v -> items.stream().anyMatch(e -> e.getId().equals(v.getId()))).findFirst().orElse(null);
                if (update != null) {
                    update.setStatus("3");
                    update.setQualifiedNum(update.getProdNum());
                    update.setEndTime(new Date());
                    update.setTenantId(items.get(0).getTenantId());
                    update.setWorkingHours(update.getEndTime().getTime() - update.getStartTime().getTime());
                    updateItems.add(update);
                }
            }
            BizDayworkItem quickItem = items.stream().filter(v -> dayworkCarriers.stream().filter(t -> allCarrier.stream().filter(e -> e.getDayworkId().equals(l.getId())).anyMatch(e -> t.getCarrierId().equals(e.getCarrierId()))).anyMatch(t -> t.getDayworkId().equals(v.getDayworkId()))).findFirst().orElse(null);
            BizQuickDayworkNextInfo quickDayworkNextInfo = items.stream().filter(e-> e.getLotId().equals(l.getLotId())).collect(Collectors.toList()).get(0).getQuickInfo();
            if (quickItem != null) {
                // 应该周转的批次 一起周转
                BizDayworkItem turnItem = new BizDayworkItem();
                turnItem.setFromDeptId(latestItem.getDeptId());
                turnItem.setFromDeptName(latestItem.getDeptName());
                turnItem.setDayworkId(latestItem.getDayworkId());
                turnItem.setProcessId(latestItem.getProcessId());
                turnItem.setTechnologicalProcessDetailId(latestItem.getTechnologicalProcessDetailId());
                // 判断是 车间内周转还是车间外周转
//                turnItem.setStatus(quickItem.getQuickInfo().getTurnoverType().equals("1") ? "7" : "4");
                turnItem.setStatus("4");
                int lotNum = currentItems.stream().mapToInt(BizDayworkItem::getQualifiedNum).sum();
                if (turnItem.getStatus().equals("7")) {
                    l.setDeptId(quickDayworkNextInfo.getDeptId());
                    l.setTemporaryProcessQualifiedNum(lotNum);
                    updateDaywork.add(l);
                }
                if(turnItem.getStatus().equals("4")){
                    l.setDeptId(quickDayworkNextInfo.getDeptId());
                    l.setTemporaryProcessQualifiedNum(lotNum);
                    updateDaywork.add(l);
                }
                turnItem.setLotId(latestItem.getLotId());
                SysUser user = SecurityUtils.getLoginUser().getUser();
                turnItem.setUserId(user.getUserId());
                turnItem.setProcessStepNumber(latestItem.getProcessStepNumber());
                turnItem.setUserName(user.getUserName());
                turnItem.setNickName(user.getNickName());
                turnItem.setTenantId(items.get(0).getTenantId());
                turnItem.setWorkingHours(0L);
                turnItem.setFormDayworkItemId(latestItem.getFormDayworkItemId());
                turnItem.setTenantId(latestItem.getTenantId());
                turnItem.setProdNum(latestItem.getProdNum());
                turnItem.setProductionPlanDetailId(latestItem.getProductionPlanDetailId());
                turnItem.setProductionPlanId(latestItem.getProductionPlanId());
                turnItem.setProductionPlanDetailSubDetailId(latestItem.getProductionPlanDetailSubDetailId());
                turnItem.setProductionPlanDetailSubDetailEquipmentId(latestItem.getProductionPlanDetailSubDetailEquipmentId());
                turnItem.setQualifiedNum(lotNum);
                turnItem.setTechnologicalProcessId(latestItem.getTechnologicalProcessId());
                turnItem.setProdNum(lotNum);
                turnItem.setEquipmentDetailId(latestItem.getEquipmentDetailId());
                turnItem.setEquipmentDetailCode(latestItem.getEquipmentDetailCode());
                turnItem.setDeptId(quickDayworkNextInfo.getDeptId());
                turnItem.setDeptName(quickDayworkNextInfo.getDeptName());
                turnItem.setStartTime(quickItem.getStartTime());
                turnItem.setTurnoverType(quickItem.getQuickInfo().getTurnoverType());
                turnItem.setTurnoverId(quickItem.getQuickInfo().getTurnoverId());
                turnItem.setTurnoverArea(quickItem.getQuickInfo().getTurnoverArea());
                turnItem.setPlaceId(quickItem.getQuickInfo().getPlaceId());
                turnItem.setPlace(quickItem.getQuickInfo().getPlace());
                turnItem.setIsQuick(1);
                addItems.add(turnItem);
            }
        }
        // 判断该周转箱是否有未完成的批次
        if (!checkFinishBatch.get()) {
            // 有未周转批次返回错误
            return error("周转箱内有批次未全部完成");
        }
        // 没有周转箱错误，完成这些报工
        //下序是否周转审核
        List<BizDayworkItem> needSortPackaging = items.stream().filter(v -> v.getQuickInfo().getIsSortPackaging() == 1).collect(Collectors.toList());
        if(!needSortPackaging.isEmpty()) {
            //判断是否已经存在审核，如果有删除
            List<Long> dayworkIds = needSortPackaging.stream().map(BizDayworkItem::getDayworkId).collect(Collectors.toList());
            List<BizDayworkItemExamine> dayworkItemExamine = bizDayworkItemExamineService.query().in("daywork_id", dayworkIds).list();
            bizDayworkItemExamineService.removeBatchByIds(dayworkItemExamine);
            List<BizDayworkItemExamine> addExamineList = new ArrayList<>();
            needSortPackaging.forEach(item -> {
                BizDayworkItemExamine examine = new BizDayworkItemExamine();
                examine.setDayworkId(item.getDayworkId());
                examine.setDayworkItemId(item.getQuickInfo().getDayworkItemId());
                examine.setDeptId(item.getQuickInfo().getDeptId());
                examine.setProductionPlanDetailId(item.getProductionPlanDetailId());
                examine.setProductDescription(item.getProductDescription());
                examine.setLotId(item.getLotId());
                examine.setLotCode(item.getLotCode());
                examine.setProductId(item.getDaywork().getProductId());
                examine.setTechnologicalProcessId(item.getTechnologicalProcessId());
                examine.setTechnologicalProcessDetailId(item.getTechnologicalProcessDetailId());
                examine.setProcessId(item.getProcess().getId());
                examine.setProcessAlias(item.getProcess().getProcessAlias());
                examine.setStatus(0);
                addExamineList.add(examine);
            });
            bizDayworkItemExamineService.saveBatch(addExamineList);
        }
        //因为需要计算箱数所以需要先保存报工信息
        boolean bool =bizDayworkItemService.updateBatchById(updateItems);
        //保存箱数
        bizDayworkItemService.saveCarrierNum(updateItems);


        return bizDayworkItemService.saveBatch(addItems) && (updateDaywork.isEmpty() || bizDayworkService.updateBatchById(updateDaywork)) && bool ? success("报工完成") : error("快速完成报工错误");
    }

    // 通过周转箱获取所有批次 和对应工序
    @PostMapping("/getDayworkByCarrierId")
    @Log(title = "快速报工扫码载具", businessType = BusinessType.SELECT)
    public AjaxResult getDayworkByCarrierId(@RequestBody BizDayworkItem bizDayworkItem) throws NoSuchFieldException, IllegalAccessException {
        // 获取快速报工的所有工段
        SysDept dept = deptService.selectDeptById(bizDayworkItem.getDeptId());
        List<BizDeptProcess> processes = deptProcessService.query().eq("dept_id", dept.getDeptId()).list();

        List<BizDeptProcess> allProcesses = deptProcessService.query().list();
        // 根据id获取资源组明细
        List<BizProductionResourceGroupDetail> detailsList = bizProductionResourceGroupDetailService.query().eq("common_type", "person").eq("common_id", SecurityUtils.getLoginUser().getUser().getUserId()).list();

        List<BizProductionResourceGroupSubPlan> groupSubPlans = bizProductionResourceGroupSubPlanService.query().in("resource_group_id", detailsList.isEmpty() ? Collections.singletonList("0") : detailsList.stream().map(BizProductionResourceGroupDetail::getProductionResourceGroupId).collect(Collectors.toList())).list();
        if (groupSubPlans.isEmpty()) {
            return success(new ArrayList<>());
        }
        BizProductionPlanDetail bizProductionPlanDetail = new BizProductionPlanDetail();
        bizProductionPlanDetail.setPlanIds(groupSubPlans.stream().map(BizProductionResourceGroupSubPlan::getProductionPlanDetailId).collect(Collectors.toList()));
        List<BizProductionPlanDetail> list = productionPlanDetailService.getInfo(bizProductionPlanDetail);
        // 判断该批次是否已被领取
        // 获取该批次最后一条的状态
        List<BizDayworkCarrier> bizDayworkCarriers = bizDayworkCarrierService.query().eq("process_inspection_id", 0L).eq("carrier_id", bizDayworkItem.getCarrierId()).eq("is_changed", 0).list();
        List<BizDaywork> bizDayworks = bizDayworkService.query().eq("dept_id", dept.getDeptId()).in("id", bizDayworkCarriers.isEmpty() ? Collections.singletonList("0") : bizDayworkCarriers.stream().map(BizDayworkCarrier::getDayworkId).collect(Collectors.toList())).list();
        List<BizDayworkItem> allBizDayworkItem = bizDayworkItemService.query().in("production_plan_detail_id", list.isEmpty() ? Collections.singletonList("0") : list.stream().map(BizProductionPlanDetail::getId).collect(Collectors.toList())).in("daywork_id", bizDayworks.isEmpty() ? Collections.singletonList("0") : bizDayworks.stream().map(BizDaywork::getId).collect(Collectors.toList())).orderByDesc("create_time").list();
//        bizDayworks.forEach(l -> l.setDayworkItemList(allBizDayworkItem.stream().filter(v -> v.getDeptId().equals(bizDayworkItem.getDeptId()) && v.getDayworkId().equals(l.getId())).collect(Collectors.toList())));
        bizDayworks.forEach(l -> l.setDayworkItemList(allBizDayworkItem.stream().filter(v -> v.getDayworkId().equals(l.getId())).collect(Collectors.toList())));

        List<BizDayworkItem> turnoverItems = new ArrayList<>();
        List<BizLotTechnologicalProcess> ltp = bizLotTechnologicalProcessService.query().eq("is_stop", 0).in("lot_id", bizDayworks.isEmpty() ? Collections.singletonList(0L) : bizDayworks.stream().map(BizDaywork::getLotId).collect(Collectors.toList())).list();
        List<BizLotTechnologicalProcessDetail> ltpd = bizLotTechnologicalProcessDetailService.query().in("lot_technological_process_id", ltp.isEmpty() ? Collections.singletonList(0L) : ltp.stream().map(BizLotTechnologicalProcess::getId).collect(Collectors.toList())).list();
        for (BizDaywork bizDaywork : bizDayworks) {
            if (!bizDaywork.getDayworkItemList().isEmpty() && (bizDaywork.getDayworkItemList().get(0).getStatus().equals("4") || bizDaywork.getDayworkItemList().get(0).getStatus().equals("7") || bizDaywork.getDayworkItemList().get(0).getStatus().equals("5"))) {
                turnoverItems.add(bizDaywork.getDayworkItemList().get(0));
            }
        }
        Map<String, Object> result = new HashMap<>();
        if (turnoverItems.isEmpty()) {
            result.put("items", turnoverItems);
            return success(result);
        } else {
            BizDayworkItem conditions = new BizDayworkItem();
            conditions.setIds(turnoverItems.stream().map(BizDayworkItem::getId).collect(Collectors.toList()));
            List<BizDayworkItem> items = bizDayworkItemService.getList(conditions);
            // 对应产品的工段
            SysDept deptConditions = new SysDept();
            setTenantId(deptConditions);
            deptConditions.setIsWorkSection(1);
            List<SysDept> depts = deptService.selectDeptList(deptConditions);
            // 对应工段的车间
            List<BizWorkshop> workshops = workshopService.query().list();
            AtomicBoolean hasNoProcess = new AtomicBoolean(false);
            items.forEach(l -> {
                BizProductionPlanDetail productionPlanDetail = list.stream().filter(v -> v.getId().equals(l.getProductionPlanDetailId())).findFirst().orElse(null);
                l.setProductionPlanNo(productionPlanDetail != null ? productionPlanDetail.getProductionPlanNo() : null);
                if (l.getDaywork().getIsAmend().equals(1) || l.getDaywork().getIsWasteRecycling().equals(1)) {
                    BizLotTechnologicalProcess p = ltp.stream().filter(v -> v.getLotId().equals(l.getDaywork().getLotId())).findFirst().orElse(new BizLotTechnologicalProcess());
                    List<BizLotTechnologicalProcessDetail> processDetails = ltpd.stream().filter(t -> t.getLotTechnologicalProcessId().equals(p.getId())).collect(Collectors.toList());
                    if (processDetails.stream().filter(v -> v.getProcessStepNumber().compareTo(l.getProcessStepNumber()) > 0).noneMatch(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getProcessId())))) {
                        hasNoProcess.set(true);
                    } else {
                        l.setProcess(processDetails.stream().filter(v -> v.getProcessStepNumber().compareTo(l.getProcessStepNumber()) > 0).filter(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getProcessId()))).map(BizProcess::new).findFirst().orElse(new BizProcess()));
                        l.setProcessSequence(processDetails.stream().map(BizProcess::new).collect(Collectors.toList()));
                        l.setNextProcess(l.getProcessSequence().stream().filter(e -> e.getProcessStepNumber().compareTo(l.getProcess().getProcessStepNumber()) > 0).min(Comparator.comparing(BizProcess::getProcessStepNumber)).orElse(null));
                        l.setNextProcesses(l.getProcess() != null ? processDetails.stream().sorted(Comparator.comparing(BizLotTechnologicalProcessDetail::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(l.getProcess().getProcessStepNumber()) > 0).map(BizProcess::new).collect(Collectors.toList()) : new ArrayList<>());
                        l.setWorkshopId(workshops.stream().filter(v -> v.getId().equals(l.getWorkshopId())).findFirst().orElse(new BizWorkshop()).getId());
                        List<SysDept> nextDept = depts.stream().filter(
                                e -> allProcesses.stream().filter(
                                        v -> l.getNextProcesses().stream().anyMatch(
                                                n -> v.getProcessId().equals(n.getId()))).anyMatch(
                                        v -> e.getDeptId().equals(v.getDeptId()))
                        ).collect(Collectors.toList());

                        workshops.forEach(e -> {
                            if (e.getDepts() == null) {
                                e.setDepts(new ArrayList<>());
                            }
                            nextDept.forEach(v -> {
                                if (v.getWorkshopId().equals(e.getId()) && e.getDepts().stream().noneMatch(n -> v.getDeptId().equals(n.getDeptId()))) {
                                    e.getDepts().add(v);
                                }
                            });
                        });
                    }

                } else {
                    BizProcess process = l.getProcessSequence().stream().filter(v -> v.getTechnologicalProcessDetailId().equals(l.getTechnologicalProcessDetailId())).findFirst().orElse(new BizProcess());
                    if (l.getProcessSequence().stream().filter(v -> v.getProcessStepNumber().compareTo(l.getProcessStepNumber()) > 0).noneMatch(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getId())))) {
                        hasNoProcess.set(true);
                    } else {
                        l.setProcess(l.getProcessSequence().stream().sorted(Comparator.comparing(BizProcess::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(process.getProcessStepNumber()) > 0).filter(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getId()))).findFirst().orElse(null));
                        l.setNextProcesses(l.getProcess() != null ? l.getProcessSequence().stream().sorted(Comparator.comparing(BizProcess::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(l.getProcess().getProcessStepNumber()) > 0).collect(Collectors.toList()) : new ArrayList<>());
                        l.setNextProcess(l.getNextProcesses().isEmpty() ? null : l.getNextProcesses().get(0));

                        l.setWorkshopId(workshops.stream().filter(v -> v.getId().equals(l.getWorkshopId())).findFirst().orElse(new BizWorkshop()).getId());
                        List<SysDept> nextDept = depts.stream().filter(e -> allProcesses.stream().filter(v -> l.getNextProcesses().stream().anyMatch(n -> v.getProcessId().equals(n.getId()))).anyMatch(v -> e.getDeptId().equals(v.getDeptId()))
                        ).collect(Collectors.toList());
                        workshops.forEach(e -> {
                            if (e.getDepts() == null) {
                                e.setDepts(new ArrayList<>());
                            }
                            nextDept.forEach(v -> {
                                if (v.getWorkshopId().equals(e.getId()) && e.getDepts().stream().noneMatch(n -> v.getDeptId().equals(n.getDeptId()))) {
                                    e.getDepts().add(v);
                                }
                            });
                        });
                    }
                }
//                BizProcess process = l.getProcessSequence().stream().filter(v -> v.getTechnologicalProcessDetailId().equals(l.getTechnologicalProcessDetailId())).findFirst().orElse(new BizProcess());
//                l.setProcess(l.getProcessSequence().stream().sorted(Comparator.comparing(BizProcess::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(process.getProcessStepNumber()) > 0).filter(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getId()))).findFirst().orElse(null));
//                l.setNextProcesses(l.getProcess() != null ? l.getProcessSequence().stream().sorted(Comparator.comparing(BizProcess::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(l.getProcess().getProcessStepNumber()) > 0).collect(Collectors.toList()) : new ArrayList<>());
//                l.setNextProcess(l.getNextProcesses().isEmpty() ? null : l.getNextProcesses().get(0));
//                BizProductionPlanDetail productionPlanDetail = list.stream().filter(v -> v.getId().equals(l.getProductionPlanDetailId())).findFirst().orElse(null);
//                l.setProductionPlanNo(productionPlanDetail != null ? productionPlanDetail.getProductionPlanNo() : null);
//                l.setWorkshopId(workshops.stream().filter(v -> v.getId().equals(l.getWorkshopId())).findFirst().orElse(new BizWorkshop()).getId());
            });
            if (hasNoProcess.get()) {
                return error("该工段没有可报工工序");
            }
            result.put("items", items);
            result.put("workShops", workshops.stream().filter(v -> !v.getDepts().isEmpty()).collect(Collectors.toList()));
            return success(result);
        }
    }

    // 通过周转箱获取所有批次 和对应工序
    @PostMapping("/getDayworkByCarrierCode")
    @Log(title = "快速报工扫码载具", businessType = BusinessType.SELECT)
    public AjaxResult getDayworkByCarrierCode(@RequestBody BizDayworkItem bizDayworkItem) throws NoSuchFieldException, IllegalAccessException {
        long tenantId = Long.parseLong(request.getHeader("tenantId"));
        // 获取快速报工的所有工段
        SysDept dept = deptService.selectDeptById(bizDayworkItem.getDeptId());
        List<BizDeptProcess> processes = deptProcessService.query().eq("dept_id", dept.getDeptId()).list();

        List<BizDeptProcess> allProcesses = deptProcessService.query().list();
        // 根据id获取资源组明细
        List<BizProductionResourceGroupDetail> detailsList = bizProductionResourceGroupDetailService.query().eq("common_type", "person").eq("common_id", SecurityUtils.getLoginUser().getUser().getUserId()).list();

        List<BizProductionResourceGroupSubPlan> groupSubPlans = bizProductionResourceGroupSubPlanService.query().in("resource_group_id", detailsList.isEmpty() ? Collections.singletonList("0") : detailsList.stream().map(BizProductionResourceGroupDetail::getProductionResourceGroupId).collect(Collectors.toList())).list();
        if (groupSubPlans.isEmpty()) {
            return success(new ArrayList<>());
        }
        BizProductionPlanDetail bizProductionPlanDetail = new BizProductionPlanDetail();
        bizProductionPlanDetail.setPlanIds(groupSubPlans.stream().map(BizProductionResourceGroupSubPlan::getProductionPlanDetailId).collect(Collectors.toList()));
        List<BizProductionPlanDetail> list = productionPlanDetailService.getInfo(bizProductionPlanDetail);
        // 判断该批次是否已被领取
        // 获取该批次最后一条的状态
        List<BizDayworkCarrier> bizDayworkCarriers = bizDayworkCarrierService.query().eq("process_inspection_id", 0L).eq("carrier_code", bizDayworkItem.getCarrierCode()).eq("is_changed", 0).list();
        List<BizDaywork> bizDayworks = bizDayworkService.query()
                .eq("dept_id", dept.getDeptId())
                .in("id", bizDayworkCarriers.isEmpty() ? Collections.singletonList("0") : bizDayworkCarriers.stream().map(BizDayworkCarrier::getDayworkId).collect(Collectors.toList())).list();

        List<BizDayworkItem> allBizDayworkItem = bizDayworkItemService.query().in("production_plan_detail_id", list.isEmpty() ? Collections.singletonList("0") : list.stream().map(BizProductionPlanDetail::getId).collect(Collectors.toList())).in("daywork_id", bizDayworks.isEmpty() ? Collections.singletonList("0") : bizDayworks.stream().map(BizDaywork::getId).collect(Collectors.toList())).orderByDesc("create_time").list();
        bizDayworks.forEach(l -> l.setDayworkItemList(allBizDayworkItem.stream().filter(v -> v.getDayworkId().equals(l.getId())).collect(Collectors.toList())));

        List<BizDayworkItem> turnoverItems = new ArrayList<>();
//        List<BizLotTechnologicalProcess> ltp = bizLotTechnologicalProcessService.query().eq("is_stop", 0).in("lot_id", bizDayworks.isEmpty() ? Collections.singletonList(0L) : bizDayworks.stream().map(BizDaywork::getLotId).collect(Collectors.toList())).list();
//        List<BizLotTechnologicalProcessDetail> ltpd = bizLotTechnologicalProcessDetailService.query().in("lot_technological_process_id", ltp.isEmpty() ? Collections.singletonList(0L) : ltp.stream().map(BizLotTechnologicalProcess::getId).collect(Collectors.toList())).list();
       List<Long> lotTechnologicalProcessIds = bizDayworks.stream().filter(item ->item.getIsAmend() == 1 || item.getIsWasteRecycling() == 1).collect(Collectors.toList()).stream().map(BizDaywork::getTechnologicalProcessId).collect(Collectors.toList());
        List<BizLotTechnologicalProcessDetail> ltpd = bizLotTechnologicalProcessDetailService.query().in("lot_technological_process_id", lotTechnologicalProcessIds.isEmpty() ? Collections.singletonList(0L) :  bizDayworks.stream().filter(item ->item.getIsAmend() == 1 || item.getIsWasteRecycling() == 1).collect(Collectors.toList()).stream().map(BizDaywork::getTechnologicalProcessId).collect(Collectors.toList())).eq("tenant_id",tenantId).list();
        for (BizDaywork bizDaywork : bizDayworks) {
            if (!bizDaywork.getDayworkItemList().isEmpty() && (bizDaywork.getDayworkItemList().get(0).getStatus().equals("4") || bizDaywork.getDayworkItemList().get(0).getStatus().equals("7") || bizDaywork.getDayworkItemList().get(0).getStatus().equals("5"))) {
                turnoverItems.add(bizDaywork.getDayworkItemList().get(0));
            }
        }
        Map<String, Object> result = new HashMap<>();
        if (turnoverItems.isEmpty()) {
            result.put("items", turnoverItems);
            return success(result);
        } else {
            BizDayworkItem conditions = new BizDayworkItem();
            conditions.setIds(turnoverItems.stream().map(BizDayworkItem::getId).collect(Collectors.toList()));
            List<BizDayworkItem> items = bizDayworkItemService.getList(conditions);
            // 对应产品的工段
            SysDept deptConditions = new SysDept();
            setTenantId(deptConditions);
            deptConditions.setIsWorkSection(1);
            List<SysDept> depts = deptService.selectDeptList(deptConditions);
            // 对应工段的车间
            List<BizWorkshop> workshops = workshopService.query().list();
            AtomicBoolean hasNoProcess = new AtomicBoolean(false);
            items.forEach(l -> {
                BizProductionPlanDetail productionPlanDetail = list.stream().filter(v -> v.getId().equals(l.getProductionPlanDetailId())).findFirst().orElse(null);
                l.setProductionPlanNo(productionPlanDetail != null ? productionPlanDetail.getProductionPlanNo() : null);
                if (l.getDaywork().getIsAmend().equals(1) || l.getDaywork().getIsWasteRecycling().equals(1)) {
                   // BizLotTechnologicalProcess p = ltp.stream().filter(v -> v.getLotId().equals(l.getDaywork().getLotId())).findFirst().orElse(new BizLotTechnologicalProcess());
                    List<BizLotTechnologicalProcessDetail> processDetails = ltpd.stream().filter(t -> t.getLotTechnologicalProcessId().equals(l.getTechnologicalProcessId())).collect(Collectors.toList());
                    if (processDetails.stream().filter(v -> v.getProcessStepNumber().compareTo(l.getProcessStepNumber()) > 0).noneMatch(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getProcessId())))) {
                        hasNoProcess.set(true);
                    } else {
                        l.setProcess(processDetails.stream().filter(v -> v.getProcessStepNumber().compareTo(l.getProcessStepNumber()) > 0).filter(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getProcessId()))).map(BizProcess::new).findFirst().orElse(new BizProcess()));
                        l.setProcessSequence(processDetails.stream().map(BizProcess::new).collect(Collectors.toList()));
                        l.setLastProcess(l.getProcessSequence().stream().filter(e -> e.getProcessStepNumber().equals(l.getProcessStepNumber())).findFirst().orElse(null));
                        l.setNextProcess(l.getProcessSequence().stream().filter(e -> e.getProcessStepNumber().compareTo(l.getProcess().getProcessStepNumber()) > 0).min(Comparator.comparing(BizProcess::getProcessStepNumber)).orElse(null));
                        l.setNextProcesses(l.getProcess() != null ? processDetails.stream().sorted(Comparator.comparing(BizLotTechnologicalProcessDetail::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(l.getProcess().getProcessStepNumber()) > 0).map(BizProcess::new).collect(Collectors.toList()) : new ArrayList<>());
                        l.setWorkshopId(workshops.stream().filter(v -> v.getId().equals(l.getWorkshopId())).findFirst().orElse(new BizWorkshop()).getId());
                        List<SysDept> nextDept = depts.stream().filter(
                                e -> allProcesses.stream().filter(
                                        v -> l.getNextProcesses().stream().anyMatch(
                                                n -> v.getProcessId().equals(n.getId()))).anyMatch(
                                        v -> e.getDeptId().equals(v.getDeptId()))
                        ).collect(Collectors.toList());

                        workshops.forEach(e -> {
                            if (e.getDepts() == null) {
                                e.setDepts(new ArrayList<>());
                            }
                            nextDept.forEach(v -> {
                                if (v.getWorkshopId().equals(e.getId()) && e.getDepts().stream().noneMatch(n -> v.getDeptId().equals(n.getDeptId()))) {
                                    e.getDepts().add(v);
                                }
                            });
                        });
                    }

                } else {
                    BizProcess process = l.getProcessSequence().stream().filter(v -> v.getTechnologicalProcessDetailId().equals(l.getTechnologicalProcessDetailId()) && v.getTenantId().equals(tenantId)).findFirst().orElse(new BizProcess());
                    if (l.getProcessSequence().stream().filter(v -> v.getProcessStepNumber().compareTo(l.getProcessStepNumber()) > 0).noneMatch(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getId())))) {
                        hasNoProcess.set(true);
                    } else {
                        l.setProcess(l.getProcessSequence().stream().sorted(Comparator.comparing(BizProcess::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(process.getProcessStepNumber()) > 0).filter(v -> processes.stream().anyMatch(e -> e.getProcessId().equals(v.getId()))).findFirst().orElse(null));
                        l.setNextProcesses(l.getProcess() != null ? l.getProcessSequence().stream().sorted(Comparator.comparing(BizProcess::getProcessStepNumber)).filter(v -> v.getProcessStepNumber().compareTo(l.getProcess().getProcessStepNumber()) > 0).collect(Collectors.toList()) : new ArrayList<>());
                        l.setNextProcess(l.getNextProcesses().isEmpty() ? null : l.getNextProcesses().get(0));
                        l.setLastProcess(l.getProcessSequence().stream().filter(e -> e.getProcessStepNumber().equals(l.getProcessStepNumber())).findFirst().orElse(null));
                        l.setWorkshopId(workshops.stream().filter(v -> v.getId().equals(l.getWorkshopId())).findFirst().orElse(new BizWorkshop()).getId());
                        List<SysDept> nextDept = depts.stream().filter(e -> "170000".equals(e.getDeptCode()) || allProcesses.stream().filter(v -> l.getNextProcesses().stream().anyMatch(n -> v.getProcessId().equals(n.getId()))).anyMatch(v -> e.getDeptId().equals(v.getDeptId()))
                        ).collect(Collectors.toList());
                        workshops.forEach(e -> {
                            if (e.getDepts() == null) {
                                e.setDepts(new ArrayList<>());
                            }
                            nextDept.forEach(v -> {
                                if (v.getWorkshopId().equals(e.getId()) && e.getDepts().stream().noneMatch(n -> v.getDeptId().equals(n.getDeptId()))) {
                                    e.getDepts().add(v);
                                }
                            });
                        });
                    }
                }
            });
            if (hasNoProcess.get()) {
                return error("该工段没有可报工工序");
            }
            //快速报工选择设备
            List<BizProductionResourceGroupDetail> productionResourceGroupDetailList = bizProductionResourceGroupDetailService.query().eq("dept_id", bizDayworkItem.getDeptId())
                    .eq("common_id", SecurityUtils.getLoginUser().getUserId()).eq("common_type", "person").list();
            if (productionResourceGroupDetailList.isEmpty()) {
                return error("当前员工未分配资源组");
            }
            List<Long> productionResourceGroupIds = productionResourceGroupDetailList.stream().map(BizProductionResourceGroupDetail::getProductionResourceGroupId).distinct().collect(Collectors.toList());
            List<BizProductionResourceGroupDetail> equipmentDetailList = bizProductionResourceGroupDetailService.query().in("production_resource_group_id", productionResourceGroupIds)
                    .eq("common_type", "equipmentDetail").inSql("common_id", "SELECT id FROM biz_equipment_detail WHERE equipment_status_code = 'NA'").list();
            result.put("items", items);
            result.put("workShops", workshops.stream().filter(v -> !v.getDepts().isEmpty()).collect(Collectors.toList()));
            result.put("equipmentDetailList", equipmentDetailList);
            return success(result);
        }
    }

    // 批量开始报工
    @PostMapping("/reportDaywork")
    @Log(title = "批量开始报工", businessType = BusinessType.INSERT)
    @Transactional
    public AjaxResult addNewDayworkItem(@RequestBody List<BizDayworkItem> dayworkItemList) {
        System.out.println("批量开始报工:"+dayworkItemList);
        SysDept sysDept = deptService.selectDeptById(dayworkItemList.get(0).getDeptId());
        // 新建报工明细
        List<BizDayworkItem> adds = new ArrayList<>();
        // 更新报工明细
        List<BizDayworkItem> updates = new ArrayList<>();
        // 更新报工
        List<BizDaywork> updateDaywork = new ArrayList<>();
        // 添加快速报工信息
        List<BizQuickDayworkNextInfo> newQuickInfos = new ArrayList<>();

        BizQuickDayworkNextInfo info = new BizQuickDayworkNextInfo();
        info.setDeptId(dayworkItemList.get(0).getQuickInfo().getDeptId());
        info.setIsSortPackaging((int)dayworkItemList.get(0).getQuickInfo().getIsSortPackaging());
        info.setWorkshopId(dayworkItemList.get(0).getQuickInfo().getWorkshopId());
        info.setDeptName(dayworkItemList.get(0).getQuickInfo().getDeptName());
        // 判断是车间内周转还是外周转
        if (!info.getWorkshopId().equals(sysDept.getWorkshopId())) {
            info.setTurnoverType("2");
            info.setTurnoverArea(bizWorkshopTurnoverService.query().eq("workshop_id", info.getWorkshopId()).eq("status",0).orderByAsc("create_time").list().get(0).getCode());
            //0628快速报工将id存入
            info.setTurnoverId(bizWorkshopTurnoverService.query().eq("workshop_id", info.getWorkshopId()).eq("status",0).orderByAsc("create_time").list().get(0).getId()+"");

            //            info.setTurnoverArea("1#东1门");
        } else {
            info.setTurnoverType("1");
            //info.setPlace("默认区");
            info.setPlace(bizTurnoverService.query().eq("dept_id",info.getDeptId()).orderByAsc("create_time").list().get(0).getCode());
            //0628快速报工将id存入
            info.setPlaceId(bizTurnoverService.query().eq("dept_id",info.getDeptId()).orderByAsc("create_time").list().get(0).getId() +"");

        }
        dayworkItemList.forEach(l -> {
            if (l.getStatus().equals("4")) {
                l.setStatus("7");
                updates.add(l);
                l.getDaywork().setDeptId(l.getDeptId());
                l.getDaywork().setProcessQualifiedNum(l.getDaywork().getTemporaryProcessQualifiedNum());
                updateDaywork.add(l.getDaywork());

                // 删除邀请报工
                BizDaywork daywork = l.getDaywork();
                daywork.setProtemProcessId(l.getProcessId());
                daywork.setProtemProcessStepNumber(l.getProcessStepNumber());
                // 如果被邀请人不是本工段内的人，则需要从当前资源组中删除被邀请人
                bizProductionResourceGroupDetailService.deleTemporanyPeople(daywork);
            } else if (l.getStatus().equals("7")) {
                // 删除邀请报工
                BizDaywork daywork = l.getDaywork();
                daywork.setProtemProcessId(l.getProcessId());
                daywork.setProtemProcessStepNumber(l.getProcessStepNumber());
                // 如果被邀请人不是本工段内的人，则需要从当前资源组中删除被邀请人
                bizProductionResourceGroupDetailService.deleTemporanyPeople(daywork);
            }
            BizDayworkItem bizDayworkItem = new BizDayworkItem();
            bizDayworkItem.setDayworkId(l.getDayworkId());
            bizDayworkItem.setStartTime(new Date());
            bizDayworkItem.setProductionPlanDetailId(l.getProductionPlanDetailId());
            bizDayworkItem.setTechnologicalProcessId(l.getDaywork().getTechnologicalProcessId());
            SysUser user = SecurityUtils.getLoginUser().getUser();
            bizDayworkItem.setUserId(user.getUserId());
            bizDayworkItem.setProcessStepNumber(l.getProcess().getProcessStepNumber());
            bizDayworkItem.setUserName(user.getUserName());
            bizDayworkItem.setNickName(user.getNickName());
            bizDayworkItem.setTenantId(l.getTenantId());
            bizDayworkItem.setEquipmentDetailCode(l.getEquipmentDetailCode());
            bizDayworkItem.setEquipmentDetailId(l.getEquipmentDetailId());
            if (l.getDaywork().getIsAmend().equals(1)) {
                bizDayworkItem.setFormDayworkItemId(1L);
            }
            //0114 这里要把前段显示的item的processId传进来
            bizDayworkItem.setProcessId(l.getDaywork().getProcessId());
            bizDayworkItem.setTechnologicalProcessDetailId(l.getDaywork().getTechnologicalProcessDetailId());
            bizDayworkItem.setDeptId(l.getDeptId());
            bizDayworkItem.setLotId(l.getDaywork().getLotId());
            bizDayworkItem.setIsQuick(1);
            bizDayworkItem.setStatus("1");
            bizDayworkItem.setProdNum(l.getQualifiedNum());
            bizDayworkItem.setDeptName(l.getDeptName());
//            bizDayworkItem.setId(snowflakeIdWorker.nextId());
            bizDayworkItemService.save(bizDayworkItem);
            BizQuickDayworkNextInfo quickInfo = new BizQuickDayworkNextInfo();
            quickInfo.setDayworkItemId(bizDayworkItem.getId());
            quickInfo.setDeptId(info.getDeptId());

            quickInfo.setPlaceId(info.getPlaceId());
            quickInfo.setPlace(info.getPlace());
            quickInfo.setLotId(bizDayworkItem.getLotId());
            quickInfo.setDeptName(info.getDeptName());
            quickInfo.setTenantId(bizDayworkItem.getTenantId());
            quickInfo.setProductionPlanDetailId(bizDayworkItem.getProductionPlanDetailId());
            quickInfo.setProductionPlanDetailSubDetailId(bizDayworkItem.getProductionPlanDetailSubDetailId());
            quickInfo.setUserId(bizDayworkItem.getUserId());
            quickInfo.setProcessId(bizDayworkItem.getProcessId());
            quickInfo.setTechnologicalProcessId(bizDayworkItem.getTechnologicalProcessId());
            quickInfo.setTechnologicalProcessDetailId(bizDayworkItem.getTechnologicalProcessDetailId());
            quickInfo.setTurnoverType(quickInfo.getDeptId().equals(114L) ? "3" : info.getTurnoverType());
//            quickInfo.setTurnoverType(info.getTurnoverType());
            quickInfo.setTurnoverArea(info.getTurnoverArea());
            quickInfo.setProductionPlanId(bizDayworkItem.getProductionPlanId());
            quickInfo.setIsSortPackaging(info.getIsSortPackaging());
            newQuickInfos.add(quickInfo);
//            adds.add(bizDayworkItem);
        });

        return toAjax(
                (updates.isEmpty() || bizDayworkItemService.updateBatchById(updates)) &&
                        (updateDaywork.isEmpty() || bizDayworkService.updateBatchById(updateDaywork)) && quickDayworkNextInfoService.saveBatch(newQuickInfos)
        );
    }

    @GetMapping("/workShopList")
    @Log(title = "获取车间列表", businessType = BusinessType.SELECT)
    public AjaxResult getWorkShopList() {
        return success(workshopService.query().list());
    }
}
