package cn.ezhizao.project.business.product.controller;

import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.project.business.product.domain.BizCarrier;
import cn.ezhizao.project.business.product.domain.BizDaywork;
import cn.ezhizao.project.business.product.domain.BizDayworkCarrier;
import cn.ezhizao.project.business.product.domain.BizDayworkItem;
import cn.ezhizao.project.business.product.service.IBizCarrierService;
import cn.ezhizao.project.business.product.service.IBizDayworkCarrierService;
import cn.ezhizao.project.business.product.service.IBizDayworkItemService;
import cn.ezhizao.project.business.product.service.IBizDayworkService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

@RestController
@RequestMapping("/business/handling")
public class HandlingController extends BaseController {
    @Resource
    private IBizDayworkItemService bizDayworkItemService;

    @Resource
    private IBizDayworkService bizDayworkService;
    @Resource
    IBizDayworkCarrierService bizDayworkCarrierService;
    @Resource
    IBizCarrierService bizCarrierService;
    @PostMapping("/getHandlingByCarrierCode")
    @Log(title = "获取载具搬运信息", businessType = BusinessType.SELECT)
    public AjaxResult getHandlingByCarrierCode(@RequestBody BizDayworkItem bizDayworkItem) {
        // 根据箱码查询周转中的批次 将所有批次都确认周转
//        String carrierCode = bizDayworkItem.getCarrierCode();
        BizCarrier bizCarrier = bizCarrierService.query().eq("code", bizDayworkItem.getCarrierCode()).one();
        if (bizCarrier == null) {
            return error("该箱号不存在");
        }
        List<BizDayworkCarrier> bizDayworkCarriers = bizDayworkCarrierService.query().eq("process_inspection_id", 0L).eq("carrier_id", bizCarrier.getId()).eq("is_changed", 0).list();
        if (bizDayworkCarriers.isEmpty()) {
            throw new RuntimeException("该载具未绑定任何批次！");
        }
        // 判断绑定批次是否已经周转中
        List<BizDaywork> bizDayworkList = bizDayworkService.query().in("id", bizDayworkCarriers.stream().map(BizDayworkCarrier::getDayworkId).collect(Collectors.toList())).list();
        List<BizDayworkItem> bizDayworkItems = bizDayworkItemService.query().in("daywork_id", bizDayworkList.stream().map(BizDaywork::getId).collect(Collectors.toList())).list();
        if (bizDayworkList.stream().anyMatch(t -> !bizDayworkItems.stream().filter(e -> e.getDayworkId().equals(t.getId())).max(Comparator.comparing(BizDayworkItem::getCreateTime)).orElse(new BizDayworkItem()).getStatus().equals("5"))) {
            return error("该载具中存在批次不在周转状态");
        }
        // 都在周转状态则 将状态改成 周转完成
        List<BizDayworkItem> updateItem = new ArrayList<>();
        bizDayworkList.forEach(l -> {
            // 获取该批次最后一条报工记录
            BizDayworkItem latestItem = bizDayworkItems.stream().filter(e -> e.getDayworkId().equals(l.getId())).max(Comparator.comparing(BizDayworkItem::getCreateTime)).orElse(null);
            if (latestItem != null) {
                latestItem.setStatus("7");
                updateItem.add(latestItem);
            }
        });
        bizDayworkItemService.updateBatchById(updateItem);
        return success();
    }
}
