package cn.ezhizao.project.business.product.domain;

import java.util.Date;
import java.util.List;

import cn.ezhizao.framework.aspectj.lang.annotation.Excel;
import cn.ezhizao.framework.web.domain.BaseEntity;
import cn.ezhizao.project.business.carrierReject.domain.BizCarrierReject;

import cn.ezhizao.project.business.inspection.domain.BizProcessInspectionPicture;
import cn.ezhizao.project.system.domain.SysUser;
import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import io.swagger.annotations.ApiModelProperty;

/**
 * 序检主对象 biz_process_inspecion
 *
 * @author ezhizao
 * @date 2024-04-24
 */
@Data
@TableName(value = "biz_process_inspecion")
public class BizProcessInspecion extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 租户（厂别）id */
    @ApiModelProperty(value = "${comment}")
    private Long tenantId;

    /** 用户id */
    @ApiModelProperty(value = "${comment}")
    private Long userId;

    /** 员工编码 */
    @Excel(name = "员工编码")
    @ApiModelProperty(value = "员工编码")
    private String userName;

    /** 员工姓名 */
    @Excel(name = "员工姓名")
    @ApiModelProperty(value = "员工姓名")
    private String nickName;

    @Excel(name = "箱号Id")
    @ApiModelProperty(value = "箱号Id")
    private Long carrierId;

    @Excel(name = "箱号code")
    @ApiModelProperty(value = "箱号code")
    private String carrierCode;

    /** daywork的id */
    @ApiModelProperty(value = "员工姓名")
    private Long dayworkId;

    /** dayworkItemId */
    private Long dayworkItemId;

    @TableField(exist = true)
    private String remark;

    /** 计划单id */
    @ApiModelProperty(value = "员工姓名")
    private Long productionPlanId;

    /** 计划单明细id */
    @ApiModelProperty(value = "员工姓名")
    private Long productionPlanDetailId;

    /** 子计划id */
    @ApiModelProperty(value = "员工姓名")
    private Long productionPlanDetailSubDetailId;

    @ApiModelProperty(value = "外协回收明细id")
    private Long returnReceiptDetailId;

    /** 批次id */
    @ApiModelProperty(value = "员工姓名")
    private Long lotId;

    /** 批次号 */
    @Excel(name = "批次号")
    @ApiModelProperty(value = "批次号")
    private String lotCode;

    /** 工段id（当前工段的id） */
    @ApiModelProperty(value = "批次号")
    private Long deptId;

    /** 产品id */
    @ApiModelProperty(value = "批次号")
    private Long productId;

    /** 检查箱号 */
    private String inspectionCarrierCode;

    /** 检查箱号id */
    private Long inspectionCarrierId;

    /** 工艺id（通过工艺id，获取版本号） */
    @ApiModelProperty(value = "批次号")
    private Long technologicalProcessId;

    /** 废品量 */
    @Excel(name = "废品量")
    @ApiModelProperty(value = "废品量")
    private Integer rejectNum;

    /** 检测量 */
    @Excel(name = "检测量")
    @ApiModelProperty(value = "检测量")
    private Integer examiningNum;

    /** 开始时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "开始时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(value = "开始时间")
    private Date startTime;

    @TableField(exist = false)
    private String startTimeString;

    @TableField(exist = false)
    private String endTimeString;

    /** 结束时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "结束时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(value = "结束时间")
    private Date endTime;

    /** 批次生产状态（0：未开始，1：进行中，2：已完成） */
    @Excel(name = "批次生产状态", readConverterExp = "0=：未开始，1：进行中，2：已完成")
    @ApiModelProperty(value = "批次生产状态")
    private Integer status;

    /** 咨询集合 */
    @TableField(exist = false)
    private List<BizDayworkItemConsult> dayworkItemConsults;

    /** 废品集合 */
    @TableField(exist = false)
    private List<BizDayworkItemReject> dayworkItemRejects;

    @TableField(exist = false)
    private List<BizProcessInspectionDetail> rejects;
    @TableField(exist = false)
    private List<BizProcessInspectionDetail> oldRejects;

    /** 产品描述 */
    private String productDescription;

    @TableField(exist = false)
    private BizLot lot;

    @TableField(exist = false)
    private SysUser user;

    @TableField(exist = false)
    private String keyword;

    @ApiModelProperty("第一修改人")
    private Long firstUpdaterId;

    @ApiModelProperty("不合格数量")
    private Integer disqualificationNum;

    @ApiModelProperty("质检箱解绑")
    private Integer isInspectionCarrierChanged;

    @ApiModelProperty("质检箱解绑时间")
    @TableField(updateStrategy = FieldStrategy.IGNORED)
    private Date inspectionCarrierChangedTime;

    @TableField(exist = false)
    private List<BizDayworkCarrier> dayworkCarriers;
    @TableField(exist = false)
    private List<BizCarrierReject> rejectCarrier;

    @ApiModelProperty("外协序检工序")
    private String processNames;
    private Long reviewerId;

    @ApiModelProperty("外协单明细id")
    private Long outsourceOrderDetailId;
    @ApiModelProperty("外协单id")
    private Long outsourceOrderId;
    @TableField(exist = false)
    private String processAlias;
    @TableField(exist = false)
    private List<BizProcessInspectionDetail> processInspectionDetails;
    // 可更新null
    @ApiModelProperty("复检时间")
    @TableField(updateStrategy = FieldStrategy.IGNORED)
    private Date recheckDate;
    @ApiModelProperty("自动外协检查")
    private Integer isAuto;
    @ApiModelProperty("外协检查单号")
    private String outsourcedInspectionNo;
    @ApiModelProperty("外协检查审核状态")
    private Integer auditStatus;
    @ApiModelProperty("是否为外协序检")
    private Integer isOutsourcedInspection;
    private String type;
    private String equipmentDetailCode;
    private Long equipmentDetailId;
    @TableField(exist = false)
    private String technicianName;
    private Long adoptId;
    private Integer adoptStatus;
    private String processStepNumber;
    private Long fromId;
    private Long inspectionChamberId;
    private Integer isAllChecked;
    private Long relatedId;
    @TableField(exist = false)
    private String technologyVersion;
    @TableField(exist = false)
    private String drawingNumber;
    //是否移交仪器室
    @TableField(exist = false)
    private Boolean flag;
    @TableField(exist = false)
    private Boolean isReviewer;
    @TableField(exist = false)
    private List<BizProcessInspectionPicture> processInspectionPictureList;
    @TableField(exist = false)
    private List<BizProcessInspecion> relateList;
    @TableField(exist = false)
    private String processCodeLabel;

    //工序编码
    @TableField(exist = false)
    private List<String> processCode;
    @TableField(exist = false)
    private BizDayworkItem dayworkItem;
    @TableField(exist = false)
    private Integer isMaster;
    @TableField(exist = false)
    private Integer isWasteRecycling;
    @TableField(exist = false)
    private Integer isAmend;
    @TableField(exist = false)
    private String reviewerName;
    private Integer inspectionStatus;

    public BizProcessInspecion() {
    }

    public BizProcessInspecion(BizProcessInspecion processInspecion) {
        this.tenantId = processInspecion.getTenantId();
        this.userId = processInspecion.getUserId();
        this.userName = processInspecion.getUserName();
        this.nickName = processInspecion.getNickName();
        this.carrierId = processInspecion.getCarrierId();
        this.carrierCode = processInspecion.getCarrierCode();
        this.dayworkId = processInspecion.getDayworkId();
        this.dayworkItemId = processInspecion.getDayworkItemId();
        this.remark = processInspecion.getRemark();
        this.productionPlanId = processInspecion.getProductionPlanId();
        this.productionPlanDetailId = processInspecion.getProductionPlanDetailId();
        this.productionPlanDetailSubDetailId = processInspecion.getProductionPlanDetailSubDetailId();
        this.returnReceiptDetailId = processInspecion.getReturnReceiptDetailId();
        this.outsourceOrderId = processInspecion.getOutsourceOrderId();
        this.lotId = processInspecion.getLotId();
        this.lotCode = processInspecion.getLotCode();
        this.deptId = processInspecion.getDeptId();
        this.productId = processInspecion.getProductId();
        this.inspectionCarrierCode = processInspecion.getInspectionCarrierCode();
        this.inspectionCarrierId = processInspecion.getInspectionCarrierId();
        this.technologicalProcessId = processInspecion.getTechnologicalProcessId();
        this.rejectNum = processInspecion.getRejectNum();
        this.examiningNum = processInspecion.getExaminingNum();
        this.startTime = processInspecion.getStartTime();
        this.startTimeString = processInspecion.getStartTimeString();
        this.endTimeString = processInspecion.getEndTimeString();
        this.endTime = processInspecion.getEndTime();
        this.status = processInspecion.getStatus();
        this.dayworkItemConsults = processInspecion.getDayworkItemConsults();
        this.dayworkItemRejects = processInspecion.getDayworkItemRejects();
        this.rejects = processInspecion.getRejects();
        this.productDescription = processInspecion.getProductDescription();
        this.lot = processInspecion.getLot();
        this.user = processInspecion.getUser();
        this.keyword = processInspecion.getKeyword();
        this.firstUpdaterId = processInspecion.getFirstUpdaterId();
        this.disqualificationNum = processInspecion.getDisqualificationNum();
        this.isInspectionCarrierChanged = processInspecion.getIsInspectionCarrierChanged();
        this.inspectionCarrierChangedTime = processInspecion.getInspectionCarrierChangedTime();
        this.dayworkCarriers = processInspecion.getDayworkCarriers();
        this.rejectCarrier = processInspecion.getRejectCarrier();
        this.processNames = processInspecion.getProcessNames();
        this.outsourceOrderDetailId = processInspecion.getOutsourceOrderDetailId();
        this.processAlias = processInspecion.getProcessAlias();
        this.processInspectionDetails = processInspecion.getProcessInspectionDetails();
        this.recheckDate = processInspecion.getRecheckDate();
        this.isAuto = processInspecion.getIsAuto();
        this.outsourcedInspectionNo = processInspecion.getOutsourcedInspectionNo();
        this.auditStatus = processInspecion.getAuditStatus();
        this.isOutsourcedInspection = processInspecion.getIsOutsourcedInspection();

    }

    @TableField(exist = false)
    private String allCarriers;
}
