package cn.ezhizao.project.business.product.service.impl;

import java.util.List;
import java.util.stream.Collectors;
import javax.annotation.Resource;

import cn.ezhizao.project.business.product.domain.BizCarrier;
import cn.ezhizao.project.business.product.domain.BizDaywork;
import cn.ezhizao.project.business.product.domain.BizDayworkItem;
import cn.ezhizao.project.business.product.mapper.BizDayworkMapper;
import cn.ezhizao.project.business.product.service.IBizDayworkService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.models.auth.In;
import org.springframework.stereotype.Service;


/**
 * 报工Service业务层处理
 *
 * @author ezhizao
 * @date 2023-11-29
 */
@Service
public class BizDayworkServiceImpl extends ServiceImpl<BizDayworkMapper, BizDaywork> implements IBizDayworkService {
    @Resource
    private BizDayworkMapper bizDayworkMapper;

    /**
     * 查询报工列表
     *
     * @param bizDaywork 报工
     * @return 报工
     */
    @Override
    public List<BizDaywork> getList(BizDaywork bizDaywork) {
        return bizDayworkMapper.getList(bizDaywork);
    }

    @Override
    public BizDaywork getDayworkInfoById(BizDaywork bizDaywork) {
        return bizDayworkMapper.getDayworkInfoById(bizDaywork);
    }

    @Override
    public List<BizDaywork> getAssistDayworkList(BizDaywork bizDaywork) {
        return bizDayworkMapper.getAssistDayworkList(bizDaywork);
    }

    /**
     * 物理删除
     * @param bizDaywork
     * @return 删除结果
     */
    @Override
    public int physicalDelete(BizDaywork bizDaywork) {
        return bizDayworkMapper.physicalDelete(bizDaywork);
    }

    @Override
    public int turnoverDelete(BizDaywork bizDaywork) {
        return bizDayworkMapper.turnoverDelete(bizDaywork);
    }

    @Override
    public List<BizCarrier> getAvailableCarrierList(BizCarrier bizCarrier) {
        return bizDayworkMapper.getAvailableCarrierList(bizCarrier);
    }

    @Override
    public BizDaywork getLotInfo(BizDaywork daywork) {
        return bizDayworkMapper.getLotInfo(daywork);
    }

    @Override
    public Integer getStatus(BizDaywork daywork) {
        //默认未开始
        Integer status = 0;
        if (!daywork.getDayworkItemList().isEmpty()) {
            boolean foundStatus3 = false;
            boolean foundStatus2 = false;
            boolean foundStatus1 = false;
            List<BizDayworkItem> currentDayworkItemList = daywork.getDayworkItemList().stream().filter(item -> item.getProcessStepNumber().equals(daywork.getCurrentProcess().getProcessStepNumber())).collect(Collectors.toList());
            List<String> currentStatusList = currentDayworkItemList.stream().map(BizDayworkItem::getStatus).collect(Collectors.toList());
            //进行中
            if ((currentStatusList.contains("1") || currentStatusList.contains("2")) && !currentStatusList.contains("3")) {
                status = 1;
            }
            //待周转
            if (currentStatusList.contains("4")) {
                status = 2;
            }
            //周转中
            if (currentStatusList.contains("5")) {
                status = 3;
            }
            //已送达
            if (currentStatusList.contains("7")) {
                status = 4;
            }
            //工序已完成
            if (currentStatusList.contains("3") && !currentStatusList.contains("4") && !currentStatusList.contains("5") && !currentStatusList.contains("7")) {
                status = 5;
            }
        }
        return status;
    }

    @Override
    public Integer getLotNumber(Long productionPlanDetailId) {
        return bizDayworkMapper.getLotNumber(productionPlanDetailId);
    }

    @Override
    public Integer getdayworkNum(Long productionPlanDetailId) {
        return bizDayworkMapper.getdayworkNum(productionPlanDetailId);
    }


}
