package cn.ezhizao.project.business.takeStockPeriod.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import cn.ezhizao.common.utils.poi.ExcelUtil;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.business.takeStockPeriod.domain.BizTakeStockPeriod;
import cn.ezhizao.project.business.takeStockPeriod.service.IBizTakeStockPeriodService;
import cn.ezhizao.project.business.taksStockLot.domain.BizTaksStockLot;
import cn.ezhizao.project.business.taksStockLot.service.IBizTaksStockLotService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 盘点时间Controller
 *
 * @author ezhizao
 * @date 2024-08-15
 */
@RestController
@RequestMapping("/business/takeStockPeriod")
public class BizTakeStockPeriodController extends BaseController
{
    @Resource
    private IBizTakeStockPeriodService bizTakeStockPeriodService;
    @Resource
    private IBizTaksStockLotService bizTaksStockLotService;
    @Resource
    private HttpServletRequest request;

    /**
     * 查询盘点时间列表
     */
    @PreAuthorize("@ss.hasPermi('business:takeStockPeriod:list')")
    @GetMapping("/list")
    @Log(title = "获取盘点列表", businessType = BusinessType.SELECT)
    public TableDataInfo list(BizTakeStockPeriod bizTakeStockPeriod) throws NoSuchFieldException, IllegalAccessException
    {
        startPage();
        List<BizTakeStockPeriod> list = bizTakeStockPeriodService.getList(bizTakeStockPeriod);
        return getDataTable(list);
    }
    @GetMapping("/getTakeStockPeriod")
    @Log(title = "获取盘点信息", businessType = BusinessType.SELECT)
    public AjaxResult getTakeStockPeriod(BizTakeStockPeriod bizTakeStockPeriod)
    {
        List<BizTakeStockPeriod> list = bizTakeStockPeriodService.query().eq("status", 1).list();
        if(!list.isEmpty()) {
            //判断该批次是否在此次盘点批次内
            List<BizTaksStockLot> taksStockLotList = bizTaksStockLotService.query().eq("take_stock_period_id", list.get(0).getId()).list();
            List<BizTaksStockLot> collect = taksStockLotList.stream().filter(item -> item.getDayworkId().equals(bizTakeStockPeriod.getDayworkId())).collect(Collectors.toList());
            return success(collect);
        }else {
            return success(new ArrayList<>());
        }
    }
    @GetMapping("/isTakeStock")
    @Log(title = "判断是否在盘点状态", businessType = BusinessType.SELECT)
    public AjaxResult isTakeStock()
    {
        Long tenantId = Long.parseLong(request.getHeader("tenantId"));
        BizTakeStockPeriod bizTakeStockPeriod = bizTakeStockPeriodService.query().eq("status",1).eq("tenant_id",tenantId).one();
        if(bizTakeStockPeriod!=null && bizTakeStockPeriod.getStatus() == 1) {
            return success(true);
        }
        return success(false);
    }

    /**
     * 导出盘点时间列表
     */
    @PreAuthorize("@ss.hasPermi('business:takeStockPeriod:export')")
    @Log(title = "导出盘点时间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizTakeStockPeriod bizTakeStockPeriod) throws NoSuchFieldException, IllegalAccessException
    {
        List<BizTakeStockPeriod> list = bizTakeStockPeriodService.getList(bizTakeStockPeriod);
        ExcelUtil<BizTakeStockPeriod> util = new ExcelUtil<BizTakeStockPeriod>(BizTakeStockPeriod.class);
        util.exportExcel(response, list, "盘点时间数据");
    }

    /**
     * 获取盘点时间详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:takeStockPeriod:query')")
    @GetMapping(value = "/{id}")
    @Log(title = "获取盘点信息", businessType = BusinessType.SELECT)
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizTakeStockPeriodService.getById(id));
    }

    /**
     * 新增盘点时间
     */
    @PreAuthorize("@ss.hasPermi('business:takeStockPeriod:add')")
    @Log(title = "新增盘点时间", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizTakeStockPeriod bizTakeStockPeriod) throws NoSuchFieldException, IllegalAccessException
    {
        return toAjax(bizTakeStockPeriodService.save(bizTakeStockPeriod));
    }

    /**
     * 修改盘点时间
     */
    @PreAuthorize("@ss.hasPermi('business:takeStockPeriod:edit')")
    @Log(title = "编辑盘点时间", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizTakeStockPeriod bizTakeStockPeriod) throws NoSuchFieldException, IllegalAccessException
    {
        return toAjax(bizTakeStockPeriodService.updateById(bizTakeStockPeriod));
    }

    /**
     * 删除盘点时间
     */
    @PreAuthorize("@ss.hasPermi('business:takeStockPeriod:remove')")
    @Log(title = "删除盘点时间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(bizTakeStockPeriodService.removeBatchByIds(ids));
    }
}
