package cn.ezhizao.project.business.technologicalProcessDetail.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import cn.ezhizao.common.utils.poi.ExcelUtil;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.business.outsource.domain.BizOutsourcedOrderDetail;
import cn.ezhizao.project.business.outsource.domain.BizOutsourcedOrderDetailProcess;
import cn.ezhizao.project.business.outsource.service.IBizOutsourcedOrderDetailProcessService;
import cn.ezhizao.project.business.outsource.service.IBizOutsourcedOrderDetailService;
import cn.ezhizao.project.business.product.domain.BizDaywork;
import cn.ezhizao.project.business.product.domain.BizLotTechnologicalProcessDetail;
import cn.ezhizao.project.business.product.service.IBizDayworkService;
import cn.ezhizao.project.business.product.service.IBizLotTechnologicalProcessDetailService;
import cn.ezhizao.project.business.technologicalProcessDetail.domain.BizTechnologicalProcessDetail;
import cn.ezhizao.project.business.technologicalProcessDetail.service.IBizTechnologicalProcessDetailService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * 工艺工序中间表Controller
 *
 * @author ezhizao
 * @date 2023-11-16
 */
@RestController
@RequestMapping("/base/technologicalProcessDetail")
public class BizTechnologicalProcessDetailController extends BaseController
{
    @Resource
    private IBizTechnologicalProcessDetailService bizTechnologicalProcessDetailService;

    @Resource
    private IBizOutsourcedOrderDetailProcessService bizOutsourcedOrderDetailProcessService;

    @Resource
    private IBizOutsourcedOrderDetailService bizOutsourcedOrderDetailService;
    @Resource
    private IBizDayworkService bizDayworkService;
    @Resource
    private IBizLotTechnologicalProcessDetailService bizLotTechnologicalProcessDetailService;
    /**
     * 查询工艺工序中间表列表
     */
    @PreAuthorize("@ss.hasPermi('base:technologicalProcessDetail:list')")
    @GetMapping("/list")
    @Log(title = "获取工艺工序列表", businessType = BusinessType.SELECT)
    public TableDataInfo list(BizTechnologicalProcessDetail bizTechnologicalProcessDetail) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizTechnologicalProcessDetail);
        startPage();
        List<BizTechnologicalProcessDetail> list = bizTechnologicalProcessDetailService.getList(bizTechnologicalProcessDetail);
        return getDataTable(list);
    }

    /**
     * 导出工艺工序中间表列表
     */
    @PreAuthorize("@ss.hasPermi('base:technologicalProcessDetail:export')")
    @Log(title = "导出工艺工序中间表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizTechnologicalProcessDetail bizTechnologicalProcessDetail) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizTechnologicalProcessDetail);
        List<BizTechnologicalProcessDetail> list = bizTechnologicalProcessDetailService.getList(bizTechnologicalProcessDetail);
        ExcelUtil<BizTechnologicalProcessDetail> util = new ExcelUtil<BizTechnologicalProcessDetail>(BizTechnologicalProcessDetail.class);
        util.exportExcel(response, list, "工艺工序中间表数据");
    }

    /**
     * 获取工艺工序中间表详细信息
     */
//    @PreAuthorize("@ss.hasPermi('base:technologicalProcessDetail:query')")
    @GetMapping(value = "/{id}")
    @Log(title = "获取工艺工序信息", businessType = BusinessType.SELECT)
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        BizTechnologicalProcessDetail byId = bizTechnologicalProcessDetailService.getById(id);
        return success(byId);
    }

    /**
     * 外协检查查询
     * 获取工艺工序中间表详细信息
     */
    @GetMapping(value = "/infoToInspecion/{id}")
    @Log(title = "外协检查查询工艺", businessType = BusinessType.SELECT)
    public AjaxResult getInfoToInspecion(@PathVariable("id") Long id)
    {
        //外协检查查询工序数据
        //1.传入的参数为外协发出明细id,查询批次发出信息
        BizOutsourcedOrderDetail orderDetail=bizOutsourcedOrderDetailService.getById(id);
        BizDaywork daywork = bizDayworkService.query().eq("id", orderDetail.getDayworkId()).one();
        //2.根据外协发出明细id查询发出工序信息
        List<BizOutsourcedOrderDetailProcess> processList=bizOutsourcedOrderDetailProcessService.query().eq("detail_id",id).list();
        List<Long> technologicalProcessDetailIds=processList.stream().map(BizOutsourcedOrderDetailProcess::getTechnologicalProcessDetailId) // 假设每个元素都有getId()方法
                .collect(Collectors.toList());
        //3.根据工序id查询所有工序信息
        if(daywork.getIsAmend() == 1 || daywork.getIsWasteRecycling() == 1) {
            List<BizLotTechnologicalProcessDetail> lotTechnologicalProcessDetailList = bizLotTechnologicalProcessDetailService.query().in("id", technologicalProcessDetailIds).list();
            List<BizTechnologicalProcessDetail> newList = new ArrayList<>();
            lotTechnologicalProcessDetailList.forEach(v->{
                BizTechnologicalProcessDetail techTechnologicalProcessDetail = new BizTechnologicalProcessDetail();
                techTechnologicalProcessDetail.setProcessAlias(v.getProcessAlias());
                techTechnologicalProcessDetail.setProcessCode(v.getProcessCode());
                newList.add(techTechnologicalProcessDetail);
            });
            orderDetail.setTechnologicalProcessDetailList(newList);
        }else {
            List<BizTechnologicalProcessDetail> technologicalProcessDetails = bizTechnologicalProcessDetailService.query().in("id", technologicalProcessDetailIds).list();
            orderDetail.setTechnologicalProcessDetailList(technologicalProcessDetails);
        }

        return success(orderDetail);
    }
    /**
     * 新增工艺工序中间表
     */
    @PreAuthorize("@ss.hasPermi('base:technologicalProcessDetail:add')")
    @Log(title = "保存工艺工序中间表", businessType = BusinessType.INSERT)
    @PostMapping("/save")
    public AjaxResult save(@RequestBody List<BizTechnologicalProcessDetail> bizTechnologicalProcessDetail)
    {

        List<BizTechnologicalProcessDetail> oldList = bizTechnologicalProcessDetailService.query().eq("technological_process_id", bizTechnologicalProcessDetail.get(0).getTechnologicalProcessId()).list();
        boolean batch = saveOrUpdateBatch(bizTechnologicalProcessDetailService, bizTechnologicalProcessDetail, oldList);
        return toAjax(batch);
    }

    /**
     * 修改工艺工序中间表
     */
    @PreAuthorize("@ss.hasPermi('base:technologicalProcessDetail:edit')")
    @Log(title = "编辑工艺工序中间表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizTechnologicalProcessDetail bizTechnologicalProcessDetail) throws NoSuchFieldException, IllegalAccessException
    {
        setTenantId(bizTechnologicalProcessDetail);
        return toAjax(bizTechnologicalProcessDetailService.updateById(bizTechnologicalProcessDetail));
    }

    /**
     * 删除工艺工序中间表
     */
    @PreAuthorize("@ss.hasPermi('base:technologicalProcessDetail:remove')")
    @Log(title = "删除工艺工序中间表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(bizTechnologicalProcessDetailService.removeBatchByIds(ids));
    }
}
