package cn.ezhizao.project.business.workshop.controller;

import cn.ezhizao.common.utils.StringUtils;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.domain.TreeSelect;
import cn.ezhizao.framework.web.domain.TreeSelectText;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.business.turnover.domain.BizTurnover;
import cn.ezhizao.project.business.workshop.domain.BizWorkshop;
import cn.ezhizao.project.business.workshop.domain.BizWorkshopTurnover;
import cn.ezhizao.project.business.workshop.service.IBizWorkshopService;
import cn.ezhizao.project.business.workshop.service.IBizWorkshopTurnoverService;
import cn.ezhizao.project.system.domain.SysDept;
import cn.ezhizao.project.system.mapper.SysDeptMapper;
import cn.ezhizao.project.system.service.ISysConfigService;
import cn.ezhizao.project.system.service.ISysDeptService;
import cn.hutool.core.lang.tree.Tree;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.web.HttpRequestHandler;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * 周转区Controller
 *
 * @author zhuangdezheng
 * @date 2024-04-20
 */
@RestController
@RequestMapping("/business/workshop")
public class BizWorkshopController extends BaseController {
    @Resource
    private ISysDeptService iSysDeptService;

    @Resource
    private IBizWorkshopTurnoverService iBizWorkshopTurnoverService;
    @Resource
    private IBizWorkshopService bizWorkshopService;
    @Resource
    private SysDeptMapper sysDeptMapper;
    @Resource
    private ISysConfigService sysConfigService;
    @Resource
    private HttpServletRequest request;
    /**
     * 查询周转区列表
     */
//    @PreAuthorize("@ss.hasPermi('business:workshop:turnover')")
    @Log(title = "查询周转区列表", businessType = BusinessType.SELECT)
    @PostMapping("/turnover")
    public AjaxResult turnover(@RequestBody Map<String, Object> data) throws NoSuchFieldException, IllegalAccessException {
        long deptId = Long.parseLong(data.get("deptId").toString());
        long tenantId = Long.parseLong(request.getHeader("tenantId"));
        SysDept dept = iSysDeptService.selectDeptById(deptId);
        List<BizWorkshopTurnover> workshopTurnovers = new ArrayList<>();
          workshopTurnovers = iBizWorkshopTurnoverService.query()
                    .eq("workshop_id", dept.getWorkshopId())
                    .eq("status",0)
                    .eq("tenant_id",tenantId)
                    .list();

        return success(workshopTurnovers);
    }
    @PostMapping("/outsourceTurnover")
    @Log(title = "外协周转区查询", businessType = BusinessType.SELECT)
    public AjaxResult outsourceTurnover(@RequestBody Map<String, Object> data) throws NoSuchFieldException, IllegalAccessException {
        String deptCode = (data.get("deptCode").toString());
        SysDept sysDept = sysDeptMapper.selectDeptByCode(deptCode);
        List<BizWorkshopTurnover> workshopTurnovers = iBizWorkshopTurnoverService.query()
                .eq("workshop_id", sysDept.getWorkshopId())
                .eq("status",0)
                .list();

        return success(workshopTurnovers);
    }

    @PostMapping("/getTreeData")
    @Log(title = "获取周转区树状结构", businessType = BusinessType.SELECT)
    public AjaxResult getTreeData () {
        QueryWrapper<BizWorkshop> queryWrapper = new QueryWrapper();
        queryWrapper.eq("tenant_id", Long.parseLong(request.getHeader("tenantId")));
        List<BizWorkshop> workshop = bizWorkshopService.list(queryWrapper);
        List<BizWorkshopTurnover> workshopTurnovers = iBizWorkshopTurnoverService.query().eq("status", 0).list();
        List<TreeSelectText> treeSelectTexts = workshop.stream().map(i -> {
            TreeSelectText item = new TreeSelectText(i);
            item.setChildren(workshopTurnovers.stream().filter(e -> e.getWorkshopId().equals(i.getId())).map(TreeSelectText::new).collect(Collectors.toList()));
            return item ;
        }).collect(Collectors.toList());
        return success(treeSelectTexts);
    }
}
