package cn.ezhizao.project.system.controller;

import cn.ezhizao.common.constant.UserConstants;
import cn.ezhizao.common.utils.SecurityUtils;
import cn.ezhizao.common.utils.StringUtils;
import cn.ezhizao.common.utils.poi.ExcelUtil;
import cn.ezhizao.framework.aspectj.lang.annotation.Log;
import cn.ezhizao.framework.aspectj.lang.enums.BusinessType;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.framework.web.page.TableDataInfo;
import cn.ezhizao.project.system.domain.SysDept;
import cn.ezhizao.project.system.domain.SysDeptUser;
import cn.ezhizao.project.system.domain.SysRole;
import cn.ezhizao.project.system.domain.SysUser;
import cn.ezhizao.project.system.service.*;
import cn.ezhizao.project.tenant.domain.BizUserTenant;
import cn.ezhizao.project.tenant.service.IBizUserTenantService;
import org.apache.commons.lang3.ArrayUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 用户信息
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/user")
public class SysUserController extends BaseController {
    @Resource
    private ISysUserService userService;

    @Resource
    private ISysRoleService roleService;

    @Resource
    private ISysDeptService deptService;

    @Resource
    private ISysPostService postService;

    @Resource
    private IBizUserTenantService userTenantService;

    @Resource
    private HttpServletRequest request;
    @Resource
    private ISysDeptUserService deptUserService;

    /**
     * 获取用户列表
     */
    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysUser user) throws NoSuchFieldException, IllegalAccessException {
        startPage();
        setTenantId(user);
        List<SysUser> list = userService.selectUserList(user);
        return getDataTable(list);
    }
    @GetMapping("/listEmployee")
    public TableDataInfo listEmployee(SysUser user) throws NoSuchFieldException, IllegalAccessException {
        startPage();
        setTenantId(user);
        List<SysUser> list = userService.selectEmployeeList(user);
        return getDataTable(list);
    }

    /**
     * 获取中间表信息
     */
    @GetMapping("/deptUser")
    public TableDataInfo deptUser(SysDeptUser deptUser) {
        startPage();
        List<SysDeptUser> list = deptUserService.getList(deptUser);
        return getDataTable(list);
    }

    /**
     * 获取nickName
     */
    @GetMapping("/getNickNameByUserName")
    public AjaxResult getNickNameByUserName(String userName) {
        String nickName = userService.selectUserNicknameByUserName(userName);
        return success(nickName);
    }

    /**
     * 获取用户部门
     */
    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @PostMapping("/getUsersByDeptId")
    public TableDataInfo getUsersByDeptId(@RequestBody Map<String, Object> data) {
        Long deptId = Long.parseLong(data.get("deptId").toString());
        startPage();
        List<SysUser> list = userService.getListByDept(deptId);
        return getDataTable(list);
    }

    @Log(title = "用户管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('system:user:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysUser user) throws NoSuchFieldException, IllegalAccessException {
        List<SysUser> list;
        if (user.getIds().size() > 0) {
            list = userService.selectUserListByIds(user.getIds());
        } else {
            list = userService.selectUserList(user);
        }
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        util.exportExcel(response, list, "用户数据");
    }

    @Log(title = "用户管理", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:user:import')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<SysUser> util = new ExcelUtil<>(SysUser.class);
        List<SysUser> userList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = userService.importUser(userList, updateSupport, operName);
        return success(message);
    }

    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil<SysUser> util = new ExcelUtil<>(SysUser.class);
        util.importTemplateExcel(response, "用户数据");
    }

    /**
     * 根据用户编号获取详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:user:query')")
    @GetMapping(value = {"/", "/{userId}"})
    public AjaxResult getInfo(@PathVariable(value = "userId", required = false) Long userId) {
        userService.checkUserDataScope(userId);
        AjaxResult ajax = AjaxResult.success();
        List<SysRole> roles = roleService.selectRoleAll();
        ajax.put("roles", SysUser.isAdmin(userId) ? roles : roles.stream().filter(r -> !r.isAdmin()).collect(Collectors.toList()));
        ajax.put("posts", postService.selectPostAll());
        if (StringUtils.isNotNull(userId)) {
            SysUser sysUser = userService.selectUserById(userId);
            ajax.put(AjaxResult.DATA_TAG, sysUser);
            ajax.put("postIds", postService.selectPostListByUserId(userId));
            ajax.put("roleIds", sysUser.getRoles().stream().map(SysRole::getRoleId).collect(Collectors.toList()));
        }
        return ajax;
    }

    /**
     * 新增用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:add')")
    @Log(title = "用户管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysUser user) {
        String tenantId = request.getHeader("tenantId");
        BizUserTenant userTenant = new BizUserTenant();
        if (UserConstants.NOT_UNIQUE.equals(userService.checkUserNameUnique(user))) {
            return error("新增用户'" + user.getUserName() + "'失败，登录账号已存在");
        } else if (StringUtils.isNotEmpty(user.getPhoneNumber())
                && UserConstants.NOT_UNIQUE.equals(userService.checkPhoneUnique(user))) {
            return error("新增用户'" + user.getUserName() + "'失败，手机号码已存在");
        } else if (StringUtils.isNotEmpty(user.getEmail())
                && UserConstants.NOT_UNIQUE.equals(userService.checkEmailUnique(user))) {
            return error("新增用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setCreateBy(getUsername());
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        if (StringUtils.isNotEmpty(tenantId)) {
            user.setUserType("02");
        }
        int rows = userService.insertUser(user);
        boolean bool = false;
        if (StringUtils.isNotEmpty(tenantId) && rows > 0) {
            userTenant.setUserId(user.getUserId());
            userTenant.setTenantId(Long.parseLong(tenantId));
            bool = userTenantService.save(userTenant);
        }
        return toAjax(bool);
    }

    /**
     * 新增或修改用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:add')")
    @Log(title = "用户管理", businessType = BusinessType.INSERT)
    @PostMapping(value = "save")
    @Transactional
    public AjaxResult save(@Validated @RequestBody SysUser user) {
//        String tenantId = request.getHeader("tenantId");
//        BizUserTenant userTenant = new BizUserTenant();
        if (UserConstants.NOT_UNIQUE.equals(userService.checkUserNameUnique(user))) {
            return error("新增用户'" + user.getUserName() + "'失败，登录账号已存在");
        } else if (StringUtils.isNotEmpty(user.getPhoneNumber())
                && UserConstants.NOT_UNIQUE.equals(userService.checkPhoneUnique(user))) {
            return error("新增用户'" + user.getUserName() + "'失败，手机号码已存在");
        } else if (StringUtils.isNotEmpty(user.getEmail())
                && UserConstants.NOT_UNIQUE.equals(userService.checkEmailUnique(user))) {
            return error("新增用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setCreateBy(getUsername());
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
//        if(StringUtils.isNotEmpty(tenantId)){
//            user.setUserType("02");
//        }
        int rows = 0;
        if (user.getUserId() == null) {
            rows = userService.insertUser(user);
        } else {
            user.setUpdateBy(getUsername());
            rows = userService.updateUser(user);
        }
//        boolean bool = false;
//        if(StringUtils.isNotEmpty(tenantId) && rows > 0){
//            userTenant.setUserId(user.getUserId());
//            userTenant.setUserId(user.getDeptId());
//            userTenant.setTenantId(Long.parseLong(tenantId));
//            bool = userTenantService.save(userTenant);
//        }
        return toAjax(rows);
    }

    /**
     * 新增或修改中间表用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:add')")
    @Log(title = "用户管理", businessType = BusinessType.INSERT)
    @PostMapping(value = "saveDeptUser")
    @Transactional
    public AjaxResult saveDeptUser(@Validated @RequestBody List<SysDeptUser> deptUserList) {
        List<SysDeptUser> oldList = deptUserService.query().eq("deleted", 0).eq("dept_id",deptUserList.get(0).getDeptId()).list();
        boolean batch = saveOrUpdateBatch(deptUserService, deptUserList, oldList);
        return toAjax(batch);
    }

    /**
     * 修改中间表用户是否是工段长或调机
     */
    @PreAuthorize("@ss.hasPermi('system:user:add')")
    @Log(title = "用户管理", businessType = BusinessType.INSERT)
    @PutMapping("/updateDeptUser")
    @Transactional
    public AjaxResult updateDeptUser(@RequestBody SysDeptUser data) {
        System.out.println(data);
        return toAjax(deptUserService.updateDeptUser(data));
    }

    /**
     * 修改用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SysUser user) throws NoSuchFieldException, IllegalAccessException {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        setTenantId(user);
        if (UserConstants.NOT_UNIQUE.equals(userService.checkUserNameUnique(user))) {
            return error("修改用户'" + user.getUserName() + "'失败，登录账号已存在");
        } else if (StringUtils.isNotEmpty(user.getPhoneNumber())
                && UserConstants.NOT_UNIQUE.equals(userService.checkPhoneUnique(user))) {
            return error("修改用户'" + user.getUserName() + "'失败，手机号码已存在");
        } else if (StringUtils.isNotEmpty(user.getEmail())
                && UserConstants.NOT_UNIQUE.equals(userService.checkEmailUnique(user))) {
            return error("修改用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setUpdateBy(getUsername());
        return toAjax(userService.updateUser(user));
    }

    /**
     * 删除用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:remove')")
    @Log(title = "用户管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds) {
        if (ArrayUtils.contains(userIds, getUserId())) {
            return error("当前用户不能删除");
        }
        return toAjax(userService.deleteUserByIds(userIds));
    }

    @PreAuthorize("@ss.hasPermi('system:user:remove')")
    @Log(title = "用户管理", businessType = BusinessType.DELETE)
    @PostMapping("/delDeptUser")
    public AjaxResult delDeptUser(@RequestBody List<SysDeptUser> deptUsers) {

        for (SysDeptUser item: deptUsers
             ) {
            deptUserService.deleteByDeptIdAndUserId(item);
        }

        return success();
    }
    /**
     * 重置密码
     */
    @PreAuthorize("@ss.hasPermi('system:user:resetPwd')")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PutMapping("/resetPwd")
    public AjaxResult resetPwd(@RequestBody SysUser user) {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        user.setUpdateBy(getUsername());
        return toAjax(userService.resetPwd(user));
    }

    /**
     * 状态修改
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PutMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody SysUser user) {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        user.setUpdateBy(getUsername());
        return toAjax(userService.updateUserStatus(user));
    }

    /**
     * 根据用户编号获取授权角色
     */
    @PreAuthorize("@ss.hasPermi('system:user:query')")
    @GetMapping("/authRole/{userId}")
    public AjaxResult authRole(@PathVariable("userId") Long userId) {
        AjaxResult ajax = AjaxResult.success();
        SysUser user = userService.selectUserById(userId);
        List<SysRole> roles = roleService.selectRolesByUserId(userId);
        ajax.put("user", user);
        ajax.put("roles", SysUser.isAdmin(userId) ? roles : roles.stream().filter(r -> !r.isAdmin()).collect(Collectors.toList()));
        return ajax;

    }

    /**
     * 用户授权角色
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "用户管理", businessType = BusinessType.GRANT)
    @PutMapping("/authRole")
    public AjaxResult insertAuthRole(Long userId, Long[] roleIds) {
        userService.checkUserDataScope(userId);
        userService.insertUserAuth(userId, roleIds);
        return success();
    }

    /**
     * 获取部门树列表
     */
    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @GetMapping("/deptTree")
    public AjaxResult deptTree(SysDept dept) throws NoSuchFieldException, IllegalAccessException {
        setTenantId(dept);
        return success(deptService.selectDeptTreeList(dept));
    }

    /**
     * 根据userName获取id
     */
    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @GetMapping("/getUserByCode")
    public SysUser getUserByCode(String userName) {

        return userService.getUserByCode(userName);
    }

    @GetMapping("/getUserByLikeUsername")
    public AjaxResult getUserByLikeUsername(String userName) {
        Long tenantId = getTenantId();
        return success(userService.getUserByLikeUserName(userName,tenantId));
    }
}
